@@ -104,7 +104,9 @@ _set_location_parser                    (xmlDoc  *doc,
 static gpointer
 _get_location_parser                    (xmlDoc  *doc,
                                          GError **error);
-
+static gpointer
+_set_dates_parser                       (xmlDoc  *doc,
+                                         GError **error);
 static FspDataPhotoInfo *
 _get_photo_info_from_node               (xmlNode *node);
 
@@ -293,6 +295,8 @@ _get_error_method_from_parser           (gpointer (*body_parser)
     error_method = FSP_ERROR_METHOD_SET_LOCATION;
   else if (body_parser == _get_location_parser)
     error_method = FSP_ERROR_METHOD_GET_LOCATION;
+  else if (body_parser == _set_dates_parser)
+    error_method = FSP_ERROR_METHOD_SET_DATES;
 
   return error_method;
 }
@@ -964,6 +968,14 @@ _get_location_parser                    (xmlDoc  *doc,
   return location;
 }
 
+static gpointer
+_set_dates_parser                       (xmlDoc  *doc,
+                                         GError **error)
+{
+  /* Dummy parser, as there is no response for this method */
+  return NULL;
+}
+
 static FspDataPhotoInfo *
 _get_photo_info_from_node               (xmlNode *node)
 {
@@ -1589,3 +1601,20 @@ fsp_parser_get_location                  (FspParser   *self,
   /* Return value */
   return location;
 }
+
+gpointer
+fsp_parser_set_dates                     (FspParser   *self,
+                                          const gchar *buffer,
+                                          gulong       buf_size,
+                                          GError     **error)
+{
+  g_return_val_if_fail (FSP_IS_PARSER (self), NULL);
+  g_return_val_if_fail (buffer != NULL, NULL);
+
+  /* Process the response */
+  _process_xml_response (self, buffer, buf_size,
+                         _set_dates_parser, error);
+
+  /* No return value for this method */
+  return GINT_TO_POINTER ((gint)(*error == NULL));
+}
