@@ -1,7 +1,7 @@
 /*
  * fsp-session.c
  *
- * Copyright (C) 2010-2014 Mario Sanchez Prada
+ * Copyright (C) 2010-2015 Mario Sanchez Prada
  * Authors: Mario Sanchez Prada <msanchez@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -26,11 +26,17 @@
 #include "fsp-session.h"
 
 #include <config.h>
+#include <errno.h>
 #include <gcrypt.h>
 #include <libsoup/soup.h>
+#include <pthread.h>
 #include <stdarg.h>
 #include <string.h>
 
+#if GCRYPT_VERSION_NUMBER < 0x010600
+GCRY_THREAD_OPTION_PTHREAD_IMPL;
+#endif
+
 #define FLICKR_API_BASE_URL   "https://api.flickr.com/services/rest"
 #define FLICKR_API_UPLOAD_URL "https://up.flickr.com/services/upload"
 #define FLICKR_REQUEST_TOKEN_OAUTH_URL "https://www.flickr.com/services/oauth/request_token"
@@ -127,6 +133,9 @@ enum  {
 
 /* Prototypes */
 
+static void
+_init_gcrypt                            (void);
+
 static SoupSession *
 _get_soup_session                       (FspSession *self);
 
@@ -336,6 +345,11 @@ _get_location_soup_session_cb            (SoupSession *session,
                                           SoupMessage *msg,
                                           gpointer     data);
 
+static void
+_set_dates_soup_session_cb              (SoupSession *session,
+                                         SoupMessage *msg,
+                                         gpointer     data);
+
 /* Private API */
 
 static void
@@ -492,6 +506,9 @@ fsp_session_init                        (FspSession *self)
   self->priv->using_default_proxy = TRUE;
   self->priv->proxy_uri = NULL;
 
+  /* Early gcrypt initialization */
+  _init_gcrypt ();
+
 #ifdef SOUP_VERSION_2_42
   /* soup_session_async_new() deprecated in lisoup 2.42 */
   self->priv->soup_session = soup_session_new ();
@@ -500,6 +517,33 @@ fsp_session_init                        (FspSession *self)
 #endif
 }
 
+static void
+_init_gcrypt                            (void)
+{
+  /* Apparently, we need to initialize gcrypt not to get a crash:
+     http://lists.gnupg.org/pipermail/gcrypt-devel/2003-August/000458.html
+     Because you can't know in a library whether another library has
+     already initialized the library */
+  if (!gcry_control (GCRYCTL_INITIALIZATION_FINISHED_P))
+    {
+      g_warning ("gcrypt has not been initialized yet! "
+                 "flicksoup will initialize gcrypt now, "
+                 "but consider to initialize gcrypt yourself "
+                 "at the beginning of this program.");
+#if GCRYPT_VERSION_NUMBER < 0x010600
+      gcry_control (GCRYCTL_SET_THREAD_CBS, &gcry_threads_pthread);
+#endif
+      /* Version check should be almost the very first call because it
+         makes sure that important subsystems are initialized. */
+      g_assert (gcry_check_version (LIBGCRYPT_MIN_VERSION));
+      /* Allocate a pool of 16k secure memory.  This make the secure
+         memory available and also drops privileges where needed. */
+      gcry_control (GCRYCTL_INIT_SECMEM, 16384, 0);
+      /* Tell Libgcrypt that initialization has completed. */
+      gcry_control (GCRYCTL_INITIALIZATION_FINISHED, 0);
+    }
+}
+
 static SoupSession *
 _get_soup_session                       (FspSession *self)
 {
@@ -1633,6 +1677,20 @@ _get_location_soup_session_cb            (SoupSession *session,
                          data);
 }
 
+static void
+_set_dates_soup_session_cb              (SoupSession *session,
+                                         SoupMessage *msg,
+                                         gpointer     data)
+{
+  g_assert (SOUP_IS_MESSAGE (msg));
+  g_assert (data != NULL);
+
+  /* Handle message with the right parser */
+  _handle_soup_response (msg,
+                         (FspParserFunc) fsp_parser_set_dates,
+                         data);
+}
+
 /* Public API */
 
 FspSession *
@@ -2690,3 +2748,58 @@ fsp_session_get_location_finish          (FspSession    *self,
                                               error));
   return location;
 }
+
+void
+fsp_session_set_date_posted             (FspSession          *self,
+                                         const gchar         *photo_id,
+                                         GDateTime           *date,
+                                         GCancellable        *cancellable,
+                                         GAsyncReadyCallback  callback,
+                                         gpointer             data)
+{
+  SoupSession *soup_session = NULL;
+  gchar* date_str;
+  gchar *url = NULL;
+
+  g_return_if_fail (FSP_IS_SESSION (self));
+  g_return_if_fail (photo_id != NULL);
+  g_return_if_fail (date != NULL);
+
+  /* The flickr API expects a UTC Unix timestamp for 'date_posted' */
+  date_str = g_date_time_format (date, "%s");
+
+  /* Build the signed url */
+  url = _get_signed_url (self,
+                         FLICKR_API_BASE_URL,
+                         AUTHORIZATION_METHOD_OAUTH_1,
+                         TOKEN_TYPE_PERMANENT,
+                         "method", "flickr.photos.setDates",
+                         "photo_id", photo_id,
+                         "date_posted", date_str,
+                         NULL);
+
+  /* Perform the async request */
+  soup_session = _get_soup_session (self);
+  _perform_async_request (soup_session, url,
+                          _set_dates_soup_session_cb, G_OBJECT (self),
+                          cancellable, callback, fsp_session_set_date_posted, data);
+
+  g_free (date_str);
+  g_free (url);
+}
+
+gboolean
+fsp_session_set_date_posted_finish      (FspSession    *self,
+                                         GAsyncResult  *res,
+                                         GError       **error)
+{
+  gpointer result = NULL;
+
+  g_return_val_if_fail (FSP_IS_SESSION (self), FALSE);
+  g_return_val_if_fail (G_IS_ASYNC_RESULT (res), FALSE);
+
+  result = _finish_async_request (G_OBJECT (self), res,
+                                  fsp_session_set_date_posted, error);
+
+  return result ? TRUE : FALSE;
+}
