@@ -1,7 +1,7 @@
 /*
  * frogr-add-tags-dialog.c -- Frogr 'add tags' dialog
  *
- * Copyright (C) 2009-2014 Mario Sanchez Prada
+ * Copyright (C) 2009-2015 Mario Sanchez Prada
  * Authors: Mario Sanchez Prada <msanchez@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -189,8 +189,8 @@ static void
 frogr_add_tags_dialog_init (FrogrAddTagsDialog *self)
 {
   FrogrAddTagsDialogPrivate *priv = FROGR_ADD_TAGS_DIALOG_GET_PRIVATE (self);
+  GtkWidget *content_area = NULL;
   GtkWidget *vbox = NULL;
-  GtkWidget *align = NULL;
   GtkWidget *label = NULL;
 
   /* Create widgets */
@@ -202,20 +202,25 @@ frogr_add_tags_dialog_init (FrogrAddTagsDialog *self)
                           NULL);
   gtk_container_set_border_width (GTK_CONTAINER (self), 6);
 
-  vbox = gtk_dialog_get_content_area (GTK_DIALOG (self));
+  content_area = gtk_dialog_get_content_area (GTK_DIALOG (self));
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+  gtk_widget_set_margin_bottom (vbox, 6);
 
   label = gtk_label_new (_("Enter a spaces separated list of tags:"));
-  align = gtk_alignment_new (0, 0, 0, 1);
-  gtk_container_add (GTK_CONTAINER (align), label);
-  gtk_box_pack_start (GTK_BOX (vbox), align, FALSE, FALSE, 6);
+  gtk_widget_set_halign (label, GTK_ALIGN_START);
+  gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 
   priv->entry = frogr_live_entry_new ();
-  gtk_box_pack_start (GTK_BOX (vbox), priv->entry, TRUE, FALSE, 6);
+  gtk_box_pack_start (GTK_BOX (vbox), priv->entry, FALSE, FALSE, 0);
 
   gtk_widget_set_size_request (GTK_WIDGET (self), 300, -1);
 
+  gtk_container_add (GTK_CONTAINER (content_area), vbox);
+
   g_signal_connect (G_OBJECT (self), "response",
                     G_CALLBACK (_dialog_response_cb), NULL);
+
+  gtk_dialog_set_default_response (GTK_DIALOG (self), GTK_RESPONSE_ACCEPT);
 }
 
 /* Public API */
@@ -231,7 +236,10 @@ frogr_add_tags_dialog_show (GtkWindow *parent, const GSList *pictures, const GSL
                       "modal", TRUE,
                       "pictures", pictures,
                       "transient-for", parent,
-                      "resizable", FALSE,
+                      "resizable", TRUE,
+#if GTK_CHECK_VERSION (3, 12, 0)
+                      "use-header-bar", USE_HEADER_BAR,
+#endif
                       NULL);
 
   /* Enable autocompletion if needed */
