@@ -1,7 +1,7 @@
 /*
  * frogr-add-to-set-dialog.c -- 'Add to set' dialog
  *
- * Copyright (C) 2010-2014 Mario Sanchez Prada
+ * Copyright (C) 2010-2015 Mario Sanchez Prada
  * Authors: Mario Sanchez Prada <msanchez@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -585,6 +585,8 @@ frogr_add_to_set_dialog_init (FrogrAddToSetDialog *self)
   g_signal_connect (G_OBJECT (self), "response",
                     G_CALLBACK (_dialog_response_cb), NULL);
 
+  gtk_dialog_set_default_response (GTK_DIALOG (self), GTK_RESPONSE_ACCEPT);
+
   gtk_window_set_default_size (GTK_WINDOW (self),
                                MINIMUM_WINDOW_WIDTH,
                                MINIMUM_WINDOW_HEIGHT);
@@ -607,6 +609,9 @@ frogr_add_to_set_dialog_show (GtkWindow *parent,
                       "photosets", photosets,
                       "transient-for", parent,
                       "resizable", TRUE,
+#if GTK_CHECK_VERSION (3, 12, 0)
+                      "use-header-bar", USE_HEADER_BAR,
+#endif
                       NULL);
 
   self = FROGR_ADD_TO_SET_DIALOG (new);
