@@ -56,6 +56,7 @@ struct _FrogrConfigPrivate
   gboolean friend;
   gboolean send_geolocation_data;
   gboolean show_in_search;
+  gboolean replace_date_posted;
 
   FspLicense license;
   FspSafetyLevel safety_level;
@@ -171,6 +172,7 @@ _load_settings (FrogrConfig *self)
   if (node && node->name && !xmlStrcmp (node->name, (const xmlChar*) "settings"))
     {
       xmlChar *version = NULL;
+      xmlChar *content = NULL;
 
       /* Check version of the settings file first */
       version = xmlGetProp (node, (const xmlChar *) "version");
@@ -180,36 +182,23 @@ _load_settings (FrogrConfig *self)
       if (version)
         xmlFree (version);
 
-      /* Iterate over children nodes and extract accounts. */
+      /* Iterate over children nodes and extract configuration options. */
       for (node = node->children; node != NULL; node = node->next)
         {
           if (node->type != XML_ELEMENT_NODE)
             continue;
 
-          if (!xmlStrcmp (node->name, (const xmlChar*) "default-license"))
-            {
-              xmlChar *content = NULL;
+          /* We must initialize this always at the beginning of the loop */
+          content = NULL;
 
-              content = xmlNodeGetContent (node);
-              if (content)
-                {
-                  gint code = 0;
+          if (!xmlStrcmp (node->name, (const xmlChar*) "mainview-options"))
+            _load_mainview_options_xml (self, xml, node);
 
-                  code = (gint) g_ascii_strtoll ((gchar *) content, NULL, 10);
-
-                  if (code < FSP_LICENSE_NONE || code >= FSP_LICENSE_LAST)
-                    priv->license = FSP_LICENSE_NONE;
-                  else
-                    priv->license = (FspLicense) code;
-
-                  xmlFree (content);
-                }
-            }
+          if (!xmlStrcmp (node->name, (const xmlChar*) "default-visibility"))
+            _load_visibility_xml (self, xml, node);
 
           if (!xmlStrcmp (node->name, (const xmlChar*) "default-content-type"))
             {
-              xmlChar *content = NULL;
-
               content = xmlNodeGetContent (node);
               if (content)
                 {
@@ -227,15 +216,11 @@ _load_settings (FrogrConfig *self)
                     default:
                       priv->content_type = FSP_CONTENT_TYPE_PHOTO;
                     }
-
-                  xmlFree (content);
                 }
             }
 
           if (!xmlStrcmp (node->name, (const xmlChar*) "default-safety-level"))
             {
-              xmlChar *content = NULL;
-
               content = xmlNodeGetContent (node);
               if (content)
                 {
@@ -253,59 +238,76 @@ _load_settings (FrogrConfig *self)
                     default:
                       priv->safety_level = FSP_SAFETY_LEVEL_SAFE;
                     }
-
-                  xmlFree (content);
                 }
             }
 
-          if (!xmlStrcmp (node->name, (const xmlChar*) "tags-autocompletion"))
+          if (!xmlStrcmp (node->name, (const xmlChar*) "default-license"))
             {
-              xmlChar *content = NULL;
-
               content = xmlNodeGetContent (node);
-              priv->tags_autocompletion = !xmlStrcmp (content, (const xmlChar*) "1");
+              if (content)
+                {
+                  gint code = 0;
 
-              xmlFree (content);
+                  code = (gint) g_ascii_strtoll ((gchar *) content, NULL, 10);
+
+                  if (code < FSP_LICENSE_NONE || code >= FSP_LICENSE_LAST)
+                    priv->license = FSP_LICENSE_NONE;
+                  else
+                    priv->license = (FspLicense) code;
+                }
             }
 
-          if (!xmlStrcmp (node->name, (const xmlChar*) "keep-file-extensions"))
+          /* By mistake, the following information was saved in the wrong place in version '1' */
+          if (g_strcmp0 (priv->settings_version, "1"))
             {
-              xmlChar *content = NULL;
+              if (!xmlStrcmp (node->name, (const xmlChar*) "default-send-geolocation-data"))
+                {
+                  content = xmlNodeGetContent (node);
+                  priv->send_geolocation_data = !xmlStrcmp (content, (const xmlChar*) "1");
+                }
 
-              content = xmlNodeGetContent (node);
-              priv->keep_file_extensions = !xmlStrcmp (content, (const xmlChar*) "1");
-
-              xmlFree (content);
+              if (!xmlStrcmp (node->name, (const xmlChar*) "default-show-in-search"))
+                {
+                  content = xmlNodeGetContent (node);
+                  priv->show_in_search = !xmlStrcmp (content, (const xmlChar*) "1");
+                }
             }
 
-          if (!xmlStrcmp (node->name, (const xmlChar*) "import-tags-from-metadata"))
+          if (!xmlStrcmp (node->name, (const xmlChar*) "default-replace-date-posted"))
             {
-              xmlChar *content = NULL;
-
               content = xmlNodeGetContent (node);
-              priv->import_tags_from_metadata = !xmlStrcmp (content, (const xmlChar*) "1");
-
-              xmlFree (content);
+              priv->replace_date_posted = !xmlStrcmp (content, (const xmlChar*) "1");
             }
 
-          if (!xmlStrcmp (node->name, (const xmlChar*) "mainview-options"))
-            _load_mainview_options_xml (self, xml, node);
-
-          if (!xmlStrcmp (node->name, (const xmlChar*) "default-visibility"))
-            _load_visibility_xml (self, xml, node);
-
           if (!xmlStrcmp (node->name, (const xmlChar*) "http-proxy"))
             _load_proxy_data_xml (self, xml, node);
 
+          if (!xmlStrcmp (node->name, (const xmlChar*) "tags-autocompletion"))
+            {
+              content = xmlNodeGetContent (node);
+              priv->tags_autocompletion = !xmlStrcmp (content, (const xmlChar*) "1");
+            }
+
+          if (!xmlStrcmp (node->name, (const xmlChar*) "import-tags-from-metadata"))
+            {
+              content = xmlNodeGetContent (node);
+              priv->import_tags_from_metadata = !xmlStrcmp (content, (const xmlChar*) "1");
+            }
+
           if (!xmlStrcmp (node->name, (const xmlChar*) "use-dark-theme"))
             {
-              xmlChar *content = NULL;
-
               content = xmlNodeGetContent (node);
               priv->use_dark_theme = !xmlStrcmp (content, (const xmlChar*) "1");
-
-              xmlFree (content);
             }
+
+          if (!xmlStrcmp (node->name, (const xmlChar*) "keep-file-extensions"))
+            {
+              content = xmlNodeGetContent (node);
+              priv->keep_file_extensions = !xmlStrcmp (content, (const xmlChar*) "1");
+            }
+
+          if (content)
+            xmlFree (content);
         }
     }
   else if (node && node->name)
@@ -366,16 +368,20 @@ _load_visibility_xml (FrogrConfig *self,
           priv->friend = !xmlStrcmp (content, (const xmlChar*) "1");
         }
 
-      if (!xmlStrcmp (node->name, (const xmlChar*) "send-geolocation-data"))
+      /* By mistake, the following information was saved in the wrong place in version '1' */
+      if (!g_strcmp0 (priv->settings_version, "1"))
         {
-          content = xmlNodeGetContent (node);
-          priv->send_geolocation_data = !xmlStrcmp (content, (const xmlChar*) "1");
-        }
+          if (!xmlStrcmp (node->name, (const xmlChar*) "send-geolocation-data"))
+            {
+              content = xmlNodeGetContent (node);
+              priv->send_geolocation_data = !xmlStrcmp (content, (const xmlChar*) "1");
+            }
 
-      if (!xmlStrcmp (node->name, (const xmlChar*) "show-in-search"))
-        {
-          content = xmlNodeGetContent (node);
-          priv->show_in_search = !xmlStrcmp (content, (const xmlChar*) "1");
+          if (!xmlStrcmp (node->name, (const xmlChar*) "show-in-search"))
+            {
+              content = xmlNodeGetContent (node);
+              priv->show_in_search = !xmlStrcmp (content, (const xmlChar*) "1");
+            }
         }
 
       if (content)
@@ -409,12 +415,8 @@ _load_mainview_options_xml (FrogrConfig *self,
 
       if (!xmlStrcmp (node->name, (const xmlChar*) "enable-tooltips"))
         {
-          xmlChar *content = NULL;
-
           content = xmlNodeGetContent (node);
           priv->mainview_enable_tooltips = !xmlStrcmp (content, (const xmlChar*) "1");
-
-          xmlFree (content);
         }
 
       if (!xmlStrcmp (node->name, (const xmlChar*) "sorting-criteria"))
@@ -690,8 +692,6 @@ _save_settings (FrogrConfig *self)
   _xml_add_bool_child (node, "public", priv->public);
   _xml_add_bool_child (node, "family", priv->family);
   _xml_add_bool_child (node, "friend", priv->friend);
-  _xml_add_bool_child (node, "send-geolocation-data", priv->send_geolocation_data);
-  _xml_add_bool_child (node, "show-in-search", priv->show_in_search);
   xmlAddChild (root, node);
 
   /* Default license */
@@ -701,17 +701,16 @@ _save_settings (FrogrConfig *self)
   _xml_add_int_child (root, "default-content-type", priv->content_type);
   _xml_add_int_child (root, "default-safety-level", priv->safety_level);
 
+  /* Other defaults */
+  _xml_add_bool_child (root, "default-send-geolocation-data", priv->send_geolocation_data);
+  _xml_add_bool_child (root, "default-show-in-search", priv->show_in_search);
+  _xml_add_bool_child (root, "default-replace-date-posted", priv->replace_date_posted);
+
   /* Other stuff */
   _xml_add_bool_child (root, "tags-autocompletion", priv->tags_autocompletion);
   _xml_add_bool_child (root, "keep-file-extensions", priv->keep_file_extensions);
   _xml_add_bool_child (root, "import-tags-from-metadata", priv->import_tags_from_metadata);
   _xml_add_bool_child (root, "use-dark-theme", priv->use_dark_theme);
-  node = xmlNewNode (NULL, (const xmlChar*) "mainview-options");
-  _xml_add_bool_child (node, "enable-tooltips", priv->mainview_enable_tooltips);
-  _xml_add_int_child (node, "sorting-criteria", priv->mainview_sorting_criteria);
-  _xml_add_bool_child (node, "sorting-reversed", priv->mainview_sorting_reversed);
-  xmlAddChild (root, node);
-
 
   /* Use proxy */
   node = xmlNewNode (NULL, (const xmlChar*) "http-proxy");
@@ -722,6 +721,13 @@ _save_settings (FrogrConfig *self)
   _xml_add_string_child (node, "proxy-password", priv->proxy_password);
   xmlAddChild (root, node);
 
+  /* Options from the 'View' menu */
+  node = xmlNewNode (NULL, (const xmlChar*) "mainview-options");
+  _xml_add_bool_child (node, "enable-tooltips", priv->mainview_enable_tooltips);
+  _xml_add_int_child (node, "sorting-criteria", priv->mainview_sorting_criteria);
+  _xml_add_bool_child (node, "sorting-reversed", priv->mainview_sorting_reversed);
+  xmlAddChild (root, node);
+
   xml_path = g_build_filename (priv->config_dir, SETTINGS_FILENAME, NULL);
 
   if (xmlSaveFormatFileEnc (xml_path, xml, "UTF-8", 1) == -1) {
@@ -981,6 +987,7 @@ frogr_config_init (FrogrConfig *self)
   priv->mainview_sorting_reversed = FALSE;
   priv->mainview_enable_tooltips = TRUE;
   priv->use_dark_theme = TRUE;
+  priv->replace_date_posted = FALSE;
   priv->use_proxy = FALSE;
   priv->proxy_host = NULL;
   priv->proxy_port = NULL;
@@ -1287,6 +1294,28 @@ frogr_config_get_default_content_type (FrogrConfig *self)
   return priv->content_type;
 }
 
+void
+frogr_config_set_default_show_in_search (FrogrConfig *self, gboolean value)
+{
+  FrogrConfigPrivate * priv = NULL;
+
+  g_return_if_fail (FROGR_IS_CONFIG (self));
+
+  priv = FROGR_CONFIG_GET_PRIVATE (self);
+  priv->show_in_search = value;
+}
+
+gboolean
+frogr_config_get_default_show_in_search (FrogrConfig *self)
+{
+  FrogrConfigPrivate *priv = NULL;
+
+  g_return_val_if_fail (FROGR_IS_CONFIG (self), FALSE);
+
+  priv = FROGR_CONFIG_GET_PRIVATE (self);
+  return priv->show_in_search;
+}
+
 void
 frogr_config_set_default_send_geolocation_data (FrogrConfig *self, gboolean value)
 {
@@ -1310,25 +1339,25 @@ frogr_config_get_default_send_geolocation_data (FrogrConfig *self)
 }
 
 void
-frogr_config_set_default_show_in_search (FrogrConfig *self, gboolean value)
+frogr_config_set_default_replace_date_posted (FrogrConfig *self, gboolean value)
 {
   FrogrConfigPrivate * priv = NULL;
 
   g_return_if_fail (FROGR_IS_CONFIG (self));
 
   priv = FROGR_CONFIG_GET_PRIVATE (self);
-  priv->show_in_search = value;
+  priv->replace_date_posted = value;
 }
 
 gboolean
-frogr_config_get_default_show_in_search (FrogrConfig *self)
+frogr_config_get_default_replace_date_posted (FrogrConfig *self)
 {
   FrogrConfigPrivate *priv = NULL;
 
   g_return_val_if_fail (FROGR_IS_CONFIG (self), FALSE);
 
   priv = FROGR_CONFIG_GET_PRIVATE (self);
-  return priv->show_in_search;
+  return priv->replace_date_posted;
 }
 
 void
