@@ -1,7 +1,7 @@
 /*
  * frogr-details-dialog.c -- Picture details dialog
  *
- * Copyright (C) 2009-2014 Mario Sanchez Prada
+ * Copyright (C) 2009-2015 Mario Sanchez Prada
  * Authors: Mario Sanchez Prada <msanchez@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -36,7 +36,7 @@
 /* Path relative to the application data dir */
 #define MPICTURES_IMAGE "/images/mpictures.png"
 
-#define DIALOG_MIN_WIDTH 640
+#define DIALOG_MIN_WIDTH 700
 #define DIALOG_MIN_HEIGHT 480
 
 #define PICTURE_WIDTH 180
@@ -57,8 +57,9 @@ typedef struct _FrogrDetailsDialogPrivate {
   GtkWidget *private_rb;
   GtkWidget *friend_cb;
   GtkWidget *family_cb;
-  GtkWidget *send_location_cb;
   GtkWidget *show_in_search_cb;
+  GtkWidget *send_location_cb;
+  GtkWidget *replace_date_posted_cb;
   GtkWidget *license_cb;
   GtkWidget *photo_content_rb;
   GtkWidget *sshot_content_rb;
@@ -149,11 +150,10 @@ _create_widgets (FrogrDetailsDialog *self)
   GtkWidget *hbox = NULL;
   GtkWidget *section_vbox = NULL;
   GtkWidget *internal_hbox = NULL;
-  GtkWidget *visibility_vbox = NULL;
   GtkWidget *private_hbox = NULL;
   GtkWidget *content_type_hbox = NULL;
   GtkWidget *safety_level_hbox = NULL;
-  GtkWidget *align = NULL;
+  GtkWidget *picture_frame = NULL;
   GtkWidget *label = NULL;
   GtkWidget *widget = NULL;
   GtkWidget *grid = NULL;
@@ -163,30 +163,32 @@ _create_widgets (FrogrDetailsDialog *self)
 
   priv = FROGR_DETAILS_DIALOG_GET_PRIVATE (self);
 
-  main_vbox = gtk_dialog_get_content_area (GTK_DIALOG (self));
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 18);
+  gtk_widget_set_margin_bottom (hbox, 6);
 
-  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-  gtk_box_set_homogeneous (GTK_BOX (hbox), FALSE);
   vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-  gtk_box_set_homogeneous (GTK_BOX (vbox), FALSE);
 
   /* Left side (image, radio buttons, checkboxes...) */
 
   grid = gtk_grid_new ();
   gtk_grid_set_row_spacing (GTK_GRID (grid), 6);
-  gtk_grid_set_column_spacing (GTK_GRID (grid), 6);
+  gtk_grid_set_column_spacing (GTK_GRID (grid), 12);
 
   widget = gtk_button_new ();
   gtk_widget_set_tooltip_text (widget, _("Open with image viewer"));
   gtk_button_set_relief (GTK_BUTTON (widget), GTK_RELIEF_NONE);
   priv->picture_button = widget;
 
-  align = gtk_alignment_new (0.6, 0, 0, 0);
-  gtk_grid_attach (GTK_GRID (grid), align, 1, 0, 1, 1);
-  priv->picture_container = align;
-  priv->picture_img = gtk_image_new ();;
+  picture_frame = gtk_frame_new (NULL);
+  gtk_frame_set_shadow_type (GTK_FRAME (picture_frame), GTK_SHADOW_NONE);
+  gtk_widget_set_halign (GTK_WIDGET (picture_frame), GTK_ALIGN_CENTER);
+
+  gtk_grid_attach (GTK_GRID (grid), picture_frame, 1, 0, 1, 1);
+  priv->picture_container = picture_frame;
+  priv->picture_img = gtk_image_new ();
 
   widget = gtk_label_new (NULL);
+  gtk_widget_set_margin_bottom (widget, 6);
   gtk_grid_attach (GTK_GRID (grid), widget, 1, 1, 1, 1);
   priv->mpictures_label = widget;
   priv->mpictures_pixbuf = NULL;
@@ -235,20 +237,17 @@ _create_widgets (FrogrDetailsDialog *self)
   gtk_grid_attach (GTK_GRID (grid), widget, 1, 4, 1, 1);
   priv->tags_entry = widget;
 
-  gtk_box_pack_start (GTK_BOX (vbox), grid, TRUE, TRUE, 6);
+  gtk_box_pack_start (GTK_BOX (vbox), grid, TRUE, TRUE, 0);
 
-  gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 6);
+  gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
 
   /* Right side (text fields) */
 
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
+
   /* Visibility */
-  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-  gtk_box_set_homogeneous (GTK_BOX (vbox), FALSE);
 
   section_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-  gtk_box_set_homogeneous (GTK_BOX (section_vbox), FALSE);
-  visibility_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-  gtk_box_set_homogeneous (GTK_BOX (visibility_vbox), FALSE);
 
   markup = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>",
                                     _("Visibility"));
@@ -256,12 +255,10 @@ _create_widgets (FrogrDetailsDialog *self)
   gtk_label_set_use_markup (GTK_LABEL (widget), TRUE);
   g_free (markup);
 
-  align = gtk_alignment_new (0, 0, 0, 0);
-  gtk_container_add (GTK_CONTAINER (align), widget);
-  gtk_box_pack_start (GTK_BOX (section_vbox), align, FALSE, FALSE, 0);
+  gtk_widget_set_halign (widget, GTK_ALIGN_START);
+  gtk_box_pack_start (GTK_BOX (section_vbox), widget, FALSE, FALSE, 0);
 
   internal_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
-  gtk_box_set_homogeneous (GTK_BOX (internal_hbox), FALSE);
 
   widget = gtk_radio_button_new_with_mnemonic (NULL, _("_Private"));
   gtk_box_pack_start (GTK_BOX (internal_hbox), widget, FALSE, FALSE, 0);
@@ -271,10 +268,10 @@ _create_widgets (FrogrDetailsDialog *self)
   gtk_box_pack_start (GTK_BOX (internal_hbox), widget, FALSE, FALSE, 0);
   priv->public_rb = widget;
 
-  gtk_box_pack_start (GTK_BOX (visibility_vbox), internal_hbox, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (section_vbox), internal_hbox, FALSE, FALSE, 0);
 
+  internal_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   private_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
-  gtk_box_set_homogeneous (GTK_BOX (private_hbox), FALSE);
 
   widget = gtk_check_button_new_with_mnemonic (_("_Family"));
   gtk_box_pack_start (GTK_BOX (private_hbox), widget, FALSE, FALSE, 0);
@@ -284,26 +281,14 @@ _create_widgets (FrogrDetailsDialog *self)
   gtk_box_pack_start (GTK_BOX (private_hbox), widget, FALSE, FALSE, 0);
   priv->friend_cb = widget;
 
-  internal_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-  gtk_box_set_homogeneous (GTK_BOX (internal_hbox), FALSE);
-
   gtk_box_pack_start (GTK_BOX (internal_hbox), private_hbox, FALSE, FALSE, 12);
-  gtk_box_pack_start (GTK_BOX (visibility_vbox), internal_hbox, FALSE, FALSE, 0);
-
-  internal_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
-  gtk_box_set_homogeneous (GTK_BOX (internal_hbox), FALSE);
-
-  gtk_box_pack_start (GTK_BOX (internal_hbox), visibility_vbox, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (section_vbox), internal_hbox, FALSE, FALSE, 0);
-
-  gtk_box_pack_start (GTK_BOX (vbox), section_vbox, FALSE, FALSE, 6);
+  gtk_box_pack_start (GTK_BOX (vbox), section_vbox, FALSE, FALSE, 0);
 
   /* Content type */
 
   section_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-  gtk_box_set_homogeneous (GTK_BOX (section_vbox), FALSE);
   content_type_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
-  gtk_box_set_homogeneous (GTK_BOX (content_type_hbox), FALSE);
 
   markup = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>",
                                     _("Content Type"));
@@ -311,9 +296,8 @@ _create_widgets (FrogrDetailsDialog *self)
   gtk_label_set_use_markup (GTK_LABEL (widget), TRUE);
   g_free (markup);
 
-  align = gtk_alignment_new (0, 0, 0, 0);
-  gtk_container_add (GTK_CONTAINER (align), widget);
-  gtk_box_pack_start (GTK_BOX (section_vbox), align, FALSE, FALSE, 0);
+  gtk_widget_set_halign (widget, GTK_ALIGN_START);
+  gtk_box_pack_start (GTK_BOX (section_vbox), widget, FALSE, FALSE, 0);
 
   widget = gtk_radio_button_new_with_mnemonic (NULL, _("P_hoto"));
   gtk_box_pack_start (GTK_BOX (content_type_hbox), widget, FALSE, FALSE, 0);
@@ -328,15 +312,12 @@ _create_widgets (FrogrDetailsDialog *self)
   priv->other_content_rb = widget;
 
   gtk_box_pack_start (GTK_BOX (section_vbox), content_type_hbox, FALSE, FALSE, 0);
-
-  gtk_box_pack_start (GTK_BOX (vbox), section_vbox, FALSE, FALSE, 6);
+  gtk_box_pack_start (GTK_BOX (vbox), section_vbox, FALSE, FALSE, 0);
 
   /* Safety level */
 
   section_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-  gtk_box_set_homogeneous (GTK_BOX (section_vbox), FALSE);
   safety_level_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
-  gtk_box_set_homogeneous (GTK_BOX (safety_level_hbox), FALSE);
 
   markup = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>",
                                     _("Safety Level"));
@@ -344,9 +325,8 @@ _create_widgets (FrogrDetailsDialog *self)
   gtk_label_set_use_markup (GTK_LABEL (widget), TRUE);
   g_free (markup);
 
-  align = gtk_alignment_new (0, 0, 0, 0);
-  gtk_container_add (GTK_CONTAINER (align), widget);
-  gtk_box_pack_start (GTK_BOX (section_vbox), align, FALSE, FALSE, 0);
+  gtk_widget_set_halign (widget, GTK_ALIGN_START);
+  gtk_box_pack_start (GTK_BOX (section_vbox), widget, FALSE, FALSE, 0);
 
   widget = gtk_radio_button_new_with_mnemonic (NULL, _("S_afe"));
   gtk_box_pack_start (GTK_BOX (safety_level_hbox), widget, FALSE, FALSE, 0);
@@ -361,13 +341,11 @@ _create_widgets (FrogrDetailsDialog *self)
   priv->restricted_rb = widget;
 
   gtk_box_pack_start (GTK_BOX (section_vbox), safety_level_hbox, FALSE, FALSE, 0);
-
-  gtk_box_pack_start (GTK_BOX (vbox), section_vbox, FALSE, FALSE, 6);
+  gtk_box_pack_start (GTK_BOX (vbox), section_vbox, FALSE, FALSE, 0);
 
   /* License type */
 
   section_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-  gtk_box_set_homogeneous (GTK_BOX (section_vbox), FALSE);
 
   markup = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>",
                                     _("License Type"));
@@ -375,23 +353,21 @@ _create_widgets (FrogrDetailsDialog *self)
   gtk_label_set_use_markup (GTK_LABEL (widget), TRUE);
   g_free (markup);
 
-  align = gtk_alignment_new (0, 0, 0, 0);
-  gtk_container_add (GTK_CONTAINER (align), widget);
-  gtk_box_pack_start (GTK_BOX (section_vbox), align, FALSE, FALSE, 0);
+  gtk_widget_set_halign (widget, GTK_ALIGN_START);
+  gtk_box_pack_start (GTK_BOX (section_vbox), widget, FALSE, FALSE, 0);
 
   widget = gtk_combo_box_text_new ();
   for (i = 0; license_descriptions[i]; i++)
     gtk_combo_box_text_insert (GTK_COMBO_BOX_TEXT (widget), i, NULL, _(license_descriptions[i]));
 
   priv->license_cb = widget;
-  gtk_box_pack_start (GTK_BOX (section_vbox), widget, FALSE, FALSE, 0);
 
-  gtk_box_pack_start (GTK_BOX (vbox), section_vbox, FALSE, FALSE, 6);
+  gtk_box_pack_start (GTK_BOX (section_vbox), widget, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), section_vbox, FALSE, FALSE, 0);
 
   /* Other properties */
 
   section_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-  gtk_box_set_homogeneous (GTK_BOX (section_vbox), FALSE);
 
   markup = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>",
                                     _("Other Properties"));
@@ -399,23 +375,27 @@ _create_widgets (FrogrDetailsDialog *self)
   gtk_label_set_use_markup (GTK_LABEL (widget), TRUE);
   g_free (markup);
 
-  align = gtk_alignment_new (0, 0, 0, 0);
-  gtk_container_add (GTK_CONTAINER (align), widget);
-  gtk_box_pack_start (GTK_BOX (section_vbox), align, FALSE, FALSE, 0);
-
-  widget = gtk_check_button_new_with_mnemonic (_("Set Geo_location Information"));
+  gtk_widget_set_halign (widget, GTK_ALIGN_START);
   gtk_box_pack_start (GTK_BOX (section_vbox), widget, FALSE, FALSE, 0);
-  priv->send_location_cb = widget;
 
   widget = gtk_check_button_new_with_mnemonic (_("_Show Up in Global Search Results"));
   gtk_box_pack_start (GTK_BOX (section_vbox), widget, FALSE, FALSE, 0);
   priv->show_in_search_cb = widget;
 
-  gtk_box_pack_start (GTK_BOX (vbox), section_vbox, FALSE, FALSE, 6);
+  widget = gtk_check_button_new_with_mnemonic (_("Set Geo_location Information"));
+  gtk_box_pack_start (GTK_BOX (section_vbox), widget, FALSE, FALSE, 0);
+  priv->send_location_cb = widget;
 
-  gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 6);
+  widget = gtk_check_button_new_with_mnemonic (_("Replace 'Date Posted' with 'Date Taken'"));
+  gtk_box_pack_start (GTK_BOX (section_vbox), widget, FALSE, FALSE, 0);
+  priv->replace_date_posted_cb = widget;
 
-  gtk_box_pack_start (GTK_BOX (main_vbox), hbox, TRUE, TRUE, 6);
+  gtk_box_pack_start (GTK_BOX (vbox), section_vbox, FALSE, FALSE, 0);
+
+  gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
+
+  main_vbox = gtk_dialog_get_content_area (GTK_DIALOG (self));
+  gtk_box_pack_start (GTK_BOX (main_vbox), hbox, TRUE, TRUE, 0);
 
   /* Connect signals */
   g_signal_connect (G_OBJECT (priv->public_rb), "clicked",
@@ -430,10 +410,13 @@ _create_widgets (FrogrDetailsDialog *self)
   g_signal_connect (G_OBJECT (priv->friend_cb), "toggled",
                     G_CALLBACK (_on_toggle_button_toggled), self);
 
+  g_signal_connect (G_OBJECT (priv->show_in_search_cb), "toggled",
+                    G_CALLBACK (_on_toggle_button_toggled), self);
+
   g_signal_connect (G_OBJECT (priv->send_location_cb), "toggled",
                     G_CALLBACK (_on_toggle_button_toggled), self);
 
-  g_signal_connect (G_OBJECT (priv->show_in_search_cb), "toggled",
+  g_signal_connect (G_OBJECT (priv->replace_date_posted_cb), "toggled",
                     G_CALLBACK (_on_toggle_button_toggled), self);
 
   g_signal_connect (G_OBJECT (priv->photo_content_rb), "clicked",
@@ -613,8 +596,9 @@ _fill_dialog_with_data (FrogrDetailsDialog *self)
   gboolean is_public_val = FALSE;
   gboolean is_friend_val = FALSE;
   gboolean is_family_val = FALSE;
-  gboolean send_location_val = FALSE;
   gboolean show_in_search_val = FALSE;
+  gboolean send_location_val = FALSE;
+  gboolean replace_date_posted_val = FALSE;
   gboolean license_inconsistent = FALSE;
   FspLicense license_val = FSP_LICENSE_NONE;
   FspSafetyLevel safety_level_val = FSP_SAFETY_LEVEL_NONE;
@@ -630,8 +614,9 @@ _fill_dialog_with_data (FrogrDetailsDialog *self)
   is_public_val = frogr_picture_is_public (picture);
   is_friend_val = frogr_picture_is_friend (picture);
   is_family_val = frogr_picture_is_family (picture);
-  send_location_val = frogr_picture_send_location (picture);
   show_in_search_val = frogr_picture_show_in_search (picture);
+  send_location_val = frogr_picture_send_location (picture);
+  replace_date_posted_val = frogr_picture_replace_date_posted (picture);
   license_val = frogr_picture_get_license (picture);
   safety_level_val = frogr_picture_get_safety_level (picture);
   content_type_val = frogr_picture_get_content_type (picture);
@@ -645,8 +630,9 @@ _fill_dialog_with_data (FrogrDetailsDialog *self)
       gboolean is_public = FALSE;
       gboolean is_friend = FALSE;
       gboolean is_family = FALSE;
-      gboolean send_location = FALSE;
       gboolean show_in_search = FALSE;
+      gboolean send_location = FALSE;
+      gboolean replace_date_posted = FALSE;
       FspLicense license = FSP_LICENSE_NONE;
       FspSafetyLevel safety_level = FSP_SAFETY_LEVEL_NONE;
       FspContentType content_type = FSP_CONTENT_TYPE_NONE;
@@ -666,8 +652,9 @@ _fill_dialog_with_data (FrogrDetailsDialog *self)
       is_public = frogr_picture_is_public (picture);
       is_friend = frogr_picture_is_friend (picture);
       is_family = frogr_picture_is_family (picture);
-      send_location = frogr_picture_send_location (picture);
       show_in_search = frogr_picture_show_in_search (picture);
+      send_location = frogr_picture_send_location (picture);
+      replace_date_posted = frogr_picture_replace_date_posted (picture);
 
       /* License */
       license = frogr_picture_get_license (picture);
@@ -713,15 +700,20 @@ _fill_dialog_with_data (FrogrDetailsDialog *self)
           gtk_toggle_button_set_inconsistent (GTK_TOGGLE_BUTTON (priv->friend_cb),
                                               is_friend_val != is_friend);
         }
+      if (!gtk_toggle_button_get_inconsistent (GTK_TOGGLE_BUTTON (priv->show_in_search_cb)))
+        {
+          gtk_toggle_button_set_inconsistent (GTK_TOGGLE_BUTTON (priv->show_in_search_cb),
+                                              show_in_search_val != show_in_search);
+        }
       if (!gtk_toggle_button_get_inconsistent (GTK_TOGGLE_BUTTON (priv->send_location_cb)))
         {
           gtk_toggle_button_set_inconsistent (GTK_TOGGLE_BUTTON (priv->send_location_cb),
                                               send_location_val != send_location);
         }
-      if (!gtk_toggle_button_get_inconsistent (GTK_TOGGLE_BUTTON (priv->show_in_search_cb)))
+      if (!gtk_toggle_button_get_inconsistent (GTK_TOGGLE_BUTTON (priv->replace_date_posted_cb)))
         {
-          gtk_toggle_button_set_inconsistent (GTK_TOGGLE_BUTTON (priv->show_in_search_cb),
-                                              show_in_search_val != show_in_search);
+          gtk_toggle_button_set_inconsistent (GTK_TOGGLE_BUTTON (priv->replace_date_posted_cb),
+                                              replace_date_posted_val != replace_date_posted);
         }
 
       if (!license_inconsistent && license_val != license)
@@ -769,8 +761,9 @@ _fill_dialog_with_data (FrogrDetailsDialog *self)
       is_public_val = is_public;
       is_friend_val = is_friend;
       is_family_val = is_family;
-      send_location_val = send_location;
       show_in_search_val = show_in_search;
+      send_location_val = send_location;
+      replace_date_posted_val = replace_date_posted;
       license_val = license;
       content_type_val = content_type;
       safety_level_val = safety_level;
@@ -800,14 +793,17 @@ _fill_dialog_with_data (FrogrDetailsDialog *self)
   if (!gtk_toggle_button_get_inconsistent (GTK_TOGGLE_BUTTON (priv->private_rb)))
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->private_rb), !is_public_val);
 
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->friend_cb),
-                                is_friend_val);
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->family_cb),
-                                is_family_val);
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->send_location_cb),
-                                send_location_val);
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->show_in_search_cb),
-                                show_in_search_val);
+  if (!gtk_toggle_button_get_inconsistent (GTK_TOGGLE_BUTTON (priv->friend_cb)))
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->friend_cb), is_friend_val);
+  if (!gtk_toggle_button_get_inconsistent (GTK_TOGGLE_BUTTON (priv->family_cb)))
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->family_cb), is_family_val);
+
+  if (!gtk_toggle_button_get_inconsistent (GTK_TOGGLE_BUTTON (priv->show_in_search_cb)))
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->show_in_search_cb), show_in_search_val);
+  if (!gtk_toggle_button_get_inconsistent (GTK_TOGGLE_BUTTON (priv->send_location_cb)))
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->send_location_cb), send_location_val);
+  if (!gtk_toggle_button_get_inconsistent (GTK_TOGGLE_BUTTON (priv->replace_date_posted_cb)))
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->replace_date_posted_cb), replace_date_posted_val);
 
   if (license_inconsistent)
     gtk_combo_box_set_active (GTK_COMBO_BOX (priv->license_cb), FSP_LICENSE_LAST + 1);
@@ -894,8 +890,9 @@ _save_data (FrogrDetailsDialog *self)
   gboolean is_public;
   gboolean is_friend;
   gboolean is_family;
-  gboolean send_location;
   gboolean show_in_search;
+  gboolean send_location;
+  gboolean replace_date_posted;
   FspLicense license;
   FspSafetyLevel safety_level;
   FspContentType content_type;
@@ -931,10 +928,12 @@ _save_data (FrogrDetailsDialog *self)
       is_family = FALSE;
     }
 
-  send_location =
-    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->send_location_cb));
   show_in_search =
     gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->show_in_search_cb));
+  send_location =
+    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->send_location_cb));
+  replace_date_posted =
+    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->replace_date_posted_cb));
 
   /* License type (values in the combo are shifted +1) */
   license = gtk_combo_box_get_active (GTK_COMBO_BOX (priv->license_cb)) - 1;
@@ -986,10 +985,12 @@ _save_data (FrogrDetailsDialog *self)
             frogr_picture_set_friend (picture, is_friend);
           if (!gtk_toggle_button_get_inconsistent (GTK_TOGGLE_BUTTON (priv->family_cb)))
             frogr_picture_set_family (picture, is_family);
-          if (!gtk_toggle_button_get_inconsistent (GTK_TOGGLE_BUTTON (priv->send_location_cb)))
-            frogr_picture_set_send_location (picture, send_location);
           if (!gtk_toggle_button_get_inconsistent (GTK_TOGGLE_BUTTON (priv->show_in_search_cb)))
             frogr_picture_set_show_in_search (picture, show_in_search);
+          if (!gtk_toggle_button_get_inconsistent (GTK_TOGGLE_BUTTON (priv->send_location_cb)))
+            frogr_picture_set_send_location (picture, send_location);
+          if (!gtk_toggle_button_get_inconsistent (GTK_TOGGLE_BUTTON (priv->replace_date_posted_cb)))
+            frogr_picture_set_replace_date_posted (picture, replace_date_posted);
 
           if (license >= FSP_LICENSE_NONE && license < FSP_LICENSE_LAST)
             frogr_picture_set_license (picture, license);
@@ -1199,8 +1200,7 @@ frogr_details_dialog_init (FrogrDetailsDialog *self)
   g_signal_connect (G_OBJECT (self), "response",
                     G_CALLBACK (_dialog_response_cb), NULL);
 
-  gtk_dialog_set_default_response (GTK_DIALOG (self),
-                                   GTK_RESPONSE_ACCEPT);
+  gtk_dialog_set_default_response (GTK_DIALOG (self), GTK_RESPONSE_ACCEPT);
 }
 
 
@@ -1222,6 +1222,9 @@ frogr_details_dialog_show (GtkWindow *parent,
                       "height-request", -1,
                       "resizable", TRUE,
                       "title", _("Edit Picture Details"),
+#if GTK_CHECK_VERSION (3, 12, 0)
+                      "use-header-bar", USE_HEADER_BAR,
+#endif
                       NULL);
 
   /* Initialize values for widgets based on the data (pictures) passed */
