@@ -81,8 +81,9 @@ struct _FrogrFileLoaderPrivate
   gboolean public_visibility;
   gboolean family_visibility;
   gboolean friend_visibility;
-  gboolean send_location;
   gboolean show_in_search;
+  gboolean send_location;
+  gboolean replace_date_posted;
   FspLicense license;
   FspSafetyLevel safety_level;
   FspContentType content_type;
@@ -549,8 +550,9 @@ _create_new_picture (FrogrFileLoader *self, GFile *file, GdkPixbuf *pixbuf, gboo
                                 priv->friend_visibility,
                                 is_video);
 
-  frogr_picture_set_send_location (picture, priv->send_location);
   frogr_picture_set_show_in_search (picture, priv->show_in_search);
+  frogr_picture_set_send_location (picture, priv->send_location);
+  frogr_picture_set_replace_date_posted (picture, priv->replace_date_posted);
   frogr_picture_set_license (picture, priv->license);
   frogr_picture_set_content_type (picture, priv->content_type);
   frogr_picture_set_safety_level (picture, priv->safety_level);
@@ -588,7 +590,7 @@ _update_picture_with_exif_data (FrogrFileLoader *self,
       ExifEntry *exif_entry = NULL;
 
       /* Date and time for picture taken */
-      exif_entry = exif_data_get_entry (exif_data, EXIF_TAG_DATE_TIME);
+      exif_entry = exif_data_get_entry (exif_data, EXIF_TAG_DATE_TIME_ORIGINAL);
       if (exif_entry)
         {
           if (exif_entry->format == EXIF_FORMAT_ASCII)
@@ -688,9 +690,11 @@ remove_spaces_from_keyword (const gchar *keyword)
 static gchar *
 import_tags_from_xmp_keywords (const char *buffer, size_t len)
 {
-  gchar *comparison_substr = NULL;
-  gchar *keywords_start = NULL;
-  gchar *keywords_end = NULL;
+  const gchar *keywords_start = NULL;
+  const gchar *keywords_end = NULL;
+  gchar *keywords_string = NULL;
+  gchar *start = NULL;
+  gchar *end = NULL;
   gchar *result = NULL;
   int i;
 
@@ -698,50 +702,49 @@ import_tags_from_xmp_keywords (const char *buffer, size_t len)
      present, that is, the keywords (aka the 'tags') */
   for (i = 0; i < len && !keywords_start; i++)
     {
-      comparison_substr = g_strndup (&buffer[i], 11);
-      if (g_str_has_prefix (comparison_substr, "<dc:subject"))
-        keywords_start = g_strdup(&buffer[i]);
-      g_free (comparison_substr);
+      if (buffer[i] != '<')
+        continue;
+
+      if (!strncmp (&buffer[i], "<dc:subject", 11))
+        keywords_start = &buffer[i];
     }
 
   /* Find the end of the interesting XMP data, if found */
-  if (keywords_start)
-    keywords_end = g_strrstr (keywords_start, "</dc:subject>");
+  if (!keywords_start)
+    return NULL;
 
-  if (keywords_end)
+  keywords_end = g_strrstr (keywords_start, "</dc:subject>");
+  if (!keywords_end)
+    return NULL;
+
+  keywords_string = g_strndup (keywords_start, keywords_end - keywords_start);
+
+  /* Remove extra not-needed stuff in the string */
+  start = g_strstr_len (keywords_string, -1, "<rdf:li");
+  end = g_strrstr (keywords_string, "</rdf:li>");
+  if (start && end)
     {
-      gchar *start = NULL;
-      gchar *end = NULL;
+      gchar **keywords = NULL;
+      gchar *keyword = NULL;
 
-      keywords_end[0] = '\0';
+      /* Get an array of strings with all the keywords */
+      end[0] = '\0';
+      keywords = g_regex_split_simple ("<.?rdf:li(!>)*>", start,
+                                       G_REGEX_DOTALL | G_REGEX_RAW, 0);
 
-      /* Remove extra not-needed stuff in the string */
-      start = g_strstr_len (keywords_start, -1, "<rdf:li");
-      end = g_strrstr (keywords_start, "</rdf:li>");
-      if (start && end)
+      /* Remove spaces to normalize to flickr tags */
+      for (i = 0; keywords[i]; i++)
         {
-          gchar **keywords = NULL;
-          gchar *keyword = NULL;
-
-          /* Get an array of strings with all the keywords */
-          end[0] = '\0';
-          keywords = g_regex_split_simple ("<.?rdf:li(!>)*>", start,
-                                           G_REGEX_DOTALL | G_REGEX_RAW, 0);
-
-          /* Remove spaces to normalize to flickr tags */
-          for (i = 0; keywords[i]; i++)
-            {
-              keyword = keywords[i];
-              keywords[i] = remove_spaces_from_keyword (keyword);
-              g_free (keyword);
-            }
-
-          result = g_strjoinv (" ", keywords);
-          g_strfreev (keywords);
+          keyword = keywords[i];
+          keywords[i] = remove_spaces_from_keyword (keyword);
+          g_free (keyword);
         }
+
+      result = g_strjoinv (" ", keywords);
+      g_strfreev (keywords);
     }
 
-  g_free (keywords_start);
+  g_free (keywords_string);
 
   return result;
 }
@@ -827,8 +830,9 @@ frogr_file_loader_init (FrogrFileLoader *self)
   priv->public_visibility = frogr_config_get_default_public (config);
   priv->family_visibility = frogr_config_get_default_family (config);
   priv->friend_visibility = frogr_config_get_default_friend (config);
-  priv->send_location = frogr_config_get_default_send_geolocation_data (config);
   priv->show_in_search = frogr_config_get_default_show_in_search (config);
+  priv->send_location = frogr_config_get_default_send_geolocation_data (config);
+  priv->replace_date_posted = frogr_config_get_default_replace_date_posted (config);
   priv->license = frogr_config_get_default_license (config);
   priv->safety_level = frogr_config_get_default_safety_level (config);
   priv->content_type = frogr_config_get_default_content_type (config);
