@@ -1,7 +1,7 @@
 /*
  * frogr-main-view.c -- Main view for the application
  *
- * Copyright (C) 2009-2014 Mario Sanchez Prada
+ * Copyright (C) 2009-2015 Mario Sanchez Prada
  *           (C) 2011 Joaquim Rocha
  * Authors:
  *   Joaquim Rocha <jrocha@igalia.com>
@@ -39,14 +39,21 @@
 /* Paths relative to the icons dir */
 #define ICON_PATH_FORMAT_STRING "%s/hicolor/%s/apps/frogr.png"
 
+#define MENU_BUTTON_ICON "open-menu-symbolic"
+#define MENU_BUTTON_ICON_FALLBACK "emblem-system-symbolic"
+
 #define MINIMUM_WINDOW_WIDTH 840
 #define MINIMUM_WINDOW_HEIGHT 600
 
 /* Path relative to the application data dir */
 #define UI_MAIN_VIEW_FILE "/gtkbuilder/frogr-main-view.xml"
 #define UI_APP_MENU_FILE "/gtkbuilder/frogr-app-menu.xml"
-#define UI_MENU_BAR_FILE "/gtkbuilder/frogr-menu-bar.xml"
 #define UI_CONTEXT_MENU_FILE "/gtkbuilder/frogr-context-menu.xml"
+#if USE_HEADER_BAR
+#define UI_MENU_BUTTON_FILE "/gtkbuilder/frogr-menu-button.xml"
+#else
+#define UI_MENU_BAR_FILE "/gtkbuilder/frogr-menu-bar.xml"
+#endif
 
 /* Action names for menu items */
 #define ACTION_AUTHORIZE "authorize"
@@ -107,6 +114,11 @@ typedef struct _FrogrMainViewPrivate {
   gchar *project_dir;
   gchar *project_filepath;
 
+  GtkApplication *gtk_app;
+
+#if USE_HEADER_BAR
+  GtkWidget *header_bar;
+#endif
   GtkWidget *icon_view;
   GtkWidget *status_bar;
 
@@ -134,13 +146,25 @@ enum {
   FPICTURE_COL
 };
 
+#if USE_HEADER_BAR
+typedef enum {
+  HEADER_BAR_POSITION_START,
+  HEADER_BAR_POSITION_END
+} HeaderBarItemPosition;
+#endif
+
 /* Prototypes */
 
 static void _initialize_ui (FrogrMainView *self);
-static void _initialize_toolbar (GtkWidget *toolbar);
 static gboolean _initialize_app_menu (FrogrMainView *self);
 
+#if USE_HEADER_BAR
+static void _initialize_header_bar (FrogrMainView *self);
+static void _add_item_to_header_bar (FrogrMainView *self, HeaderBarItemPosition pos, const gchar *action_name, const gchar *icon_name, const gchar *label, const gchar *tooltip_text, const gchar *accel);
+#else
+static void _initialize_menubar_and_toolbar (FrogrMainView *self);
 static GtkToolItem *_create_toolbar_item (const gchar *action_name, const gchar *icon_name, const gchar *label, const gchar *tooltip_text);
+#endif
 static gboolean _maybe_show_auth_dialog_on_idle (FrogrMainView *self);
 
 static void _update_project_path (FrogrMainView *self, const gchar *path);
@@ -317,7 +341,6 @@ static void
 _initialize_ui (FrogrMainView *self)
 {
   FrogrMainViewPrivate *priv = NULL;
-  GtkApplication *gtk_app;
   GtkBuilder *builder;
   GtkWidget *main_vbox;
   GtkWidget *icon_view;
@@ -326,7 +349,6 @@ _initialize_ui (FrogrMainView *self)
   GtkWidget *progress_vbox;
   GtkWidget *progress_bar;
   GtkWidget *progress_label;
-  GtkWidget *toolbar;
   GMenuModel *ctxt_menu_model;
   const gchar *icons_path = NULL;
   gchar *full_path = NULL;
@@ -367,29 +389,22 @@ _initialize_ui (FrogrMainView *self)
   gtk_builder_add_from_file (builder, full_path, NULL);
   g_free (full_path);
 
-  gtk_app = gtk_window_get_application (GTK_WINDOW (self));
-  g_action_map_add_action_entries (G_ACTION_MAP (gtk_app),
+  priv->gtk_app = gtk_window_get_application (GTK_WINDOW (self));
+  g_action_map_add_action_entries (G_ACTION_MAP (priv->gtk_app),
                                    app_entries, G_N_ELEMENTS (app_entries),
                                    self);
   priv->app_menu = G_MENU_MODEL (gtk_builder_get_object (builder, "app-menu"));
-  gtk_application_set_app_menu (GTK_APPLICATION (gtk_app), priv->app_menu);
+  gtk_application_set_app_menu (priv->gtk_app, priv->app_menu);
 
-  /* Menu bar */
-  full_path = g_strdup_printf ("%s/" UI_MENU_BAR_FILE, frogr_util_get_app_data_dir ());
-  gtk_builder_add_from_file (builder, full_path, NULL);
-  g_free (full_path);
-
-  g_action_map_add_action_entries (G_ACTION_MAP (self),
-                                   win_entries, G_N_ELEMENTS (win_entries),
-                                   self);
-
-  gtk_application_set_menubar (GTK_APPLICATION (gtk_app),
-                               G_MENU_MODEL (gtk_builder_get_object (builder, "menu-bar")));
-  gtk_application_window_set_show_menubar (GTK_APPLICATION_WINDOW (self), TRUE);
-
-  /* Toolbar */
-  toolbar = GTK_WIDGET (gtk_builder_get_object (builder, "toolbar"));
-  _initialize_toolbar (toolbar);
+#if USE_HEADER_BAR
+  /* Header_Bar and main vertical box below*/
+  _initialize_header_bar (self);
+  gtk_window_set_titlebar (GTK_WINDOW (self), priv->header_bar);
+#else
+  /* Menu bar and Toolbar */
+  _initialize_menubar_and_toolbar (self);
+  gtk_window_set_hide_titlebar_when_maximized (GTK_WINDOW (self), TRUE);
+#endif
 
   icon_view = GTK_WIDGET (gtk_builder_get_object (builder, "icon_view"));
   priv->icon_view = icon_view;
@@ -442,7 +457,7 @@ _initialize_ui (FrogrMainView *self)
                                                  _("_Cancel"),
                                                  GTK_RESPONSE_CANCEL,
                                                  NULL);
-  gtk_window_set_title (GTK_WINDOW (progress_dialog), APP_SHORTNAME);
+  gtk_window_set_title (GTK_WINDOW (progress_dialog), "");
 
   gtk_dialog_set_response_sensitive (GTK_DIALOG (progress_dialog),
                                      GTK_RESPONSE_CANCEL, TRUE);
@@ -459,6 +474,7 @@ _initialize_ui (FrogrMainView *self)
   gtk_progress_bar_set_show_text (GTK_PROGRESS_BAR (progress_bar), TRUE);
 
   gtk_box_pack_start (GTK_BOX (progress_vbox), progress_bar, FALSE, FALSE, 6);
+  gtk_widget_set_margin_bottom (progress_bar, 6);
 
   gtk_widget_hide (progress_dialog);
   priv->progress_dialog = progress_dialog;
@@ -484,7 +500,6 @@ _initialize_ui (FrogrMainView *self)
   gtk_widget_set_has_tooltip (icon_view, TRUE);
 
   gtk_window_set_default_size (GTK_WINDOW (self), MINIMUM_WINDOW_WIDTH, MINIMUM_WINDOW_HEIGHT);
-  gtk_window_set_hide_titlebar_when_maximized (GTK_WINDOW (self), TRUE);
 
   /* Init status bar */
   priv->sb_context_id =
@@ -536,26 +551,6 @@ _initialize_ui (FrogrMainView *self)
   gtk_widget_show (GTK_WIDGET (self));
 }
 
-static void _initialize_toolbar (GtkWidget *toolbar)
-{
-  GtkToolItem *toolbar_items[7];
-  gint i;
-
-  toolbar_items[0] = _create_toolbar_item ("win.open-project", "gtk-open", _("Open"), _("Open Existing Project"));
-  toolbar_items[1] = _create_toolbar_item ("win.save-project", "gtk-save", _("Save"), _("Save Current Project"));
-  toolbar_items[2] = gtk_separator_tool_item_new ();
-  toolbar_items[3] = _create_toolbar_item ("win.add-pictures", "gtk-add", _("Add"), _("Add Elements"));
-  toolbar_items[4] = _create_toolbar_item ("win.remove-pictures", "gtk-remove", _("Remove"), _("Remove Elements"));
-  toolbar_items[5] = gtk_separator_tool_item_new ();
-  toolbar_items[6] = _create_toolbar_item ("win.upload-all", "gtk-go-up", _("Upload"), _("Upload All"));
-
-  for (i = 0; i < G_N_ELEMENTS (toolbar_items); ++i)
-    gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolbar_items[i], i);
-
-  gtk_style_context_add_class (gtk_widget_get_style_context (toolbar),
-                               GTK_STYLE_CLASS_PRIMARY_TOOLBAR);
-}
-
 static gboolean
 _initialize_app_menu (FrogrMainView *self)
 {
@@ -568,6 +563,211 @@ _initialize_app_menu (FrogrMainView *self)
   return FALSE;
 }
 
+#if USE_HEADER_BAR
+
+/* This function was taken from gtkapplication.c, from gtk+, licensed
+ * under the GNU Lesser General Public License Version 2+ */
+static void
+extract_accel_from_menu_item (GMenuModel     *model,
+                              gint            item,
+                              GtkApplication *app)
+{
+  GMenuAttributeIter *iter;
+  const gchar *key;
+  GVariant *value;
+  const gchar *accel = NULL;
+  const gchar *action = NULL;
+  GVariant *target = NULL;
+
+  iter = g_menu_model_iterate_item_attributes (model, item);
+  while (g_menu_attribute_iter_get_next (iter, &key, &value))
+    {
+      if (g_str_equal (key, "action") && g_variant_is_of_type (value, G_VARIANT_TYPE_STRING))
+        action = g_variant_get_string (value, NULL);
+      else if (g_str_equal (key, "accel") && g_variant_is_of_type (value, G_VARIANT_TYPE_STRING))
+        accel = g_variant_get_string (value, NULL);
+      else if (g_str_equal (key, "target"))
+        target = g_variant_ref (value);
+      g_variant_unref (value);
+    }
+  g_object_unref (iter);
+
+  if (accel && action)
+    {
+#if GTK_CHECK_VERSION (3, 12, 0)
+      const gchar *accels[2] = { accel, NULL };
+      gtk_application_set_accels_for_action (app, action, accels);
+#else
+      gtk_application_add_accelerator (app, accel, action, target);
+#endif
+    }
+
+  if (target)
+    g_variant_unref (target);
+}
+
+/* This function was taken from gtkapplication.c, from gtk+, licensed
+ * under the GNU Lesser General Public License Version 2+ */
+static void
+extract_accels_from_menu (GMenuModel     *model,
+                          GtkApplication *app)
+{
+  gint i;
+  GMenuLinkIter *iter;
+  const gchar *key;
+  GMenuModel *m;
+
+  for (i = 0; i < g_menu_model_get_n_items (model); i++)
+    {
+      extract_accel_from_menu_item (model, i, app);
+
+      iter = g_menu_model_iterate_item_links (model, i);
+      while (g_menu_link_iter_get_next (iter, &key, &m))
+        {
+          extract_accels_from_menu (m, app);
+          g_object_unref (m);
+        }
+      g_object_unref (iter);
+    }
+}
+
+static void _initialize_header_bar (FrogrMainView *self)
+{
+  FrogrMainViewPrivate *priv = NULL;
+  GMenuModel *menu_model = NULL;
+  GtkWidget *toolbar = NULL;
+  GtkWidget *header_item = NULL;
+  GtkWidget *menu = NULL;
+  GtkWidget *menu_image = NULL;
+  GtkIconTheme *icon_theme = NULL;
+  gchar *full_path = NULL;
+
+  priv = FROGR_MAIN_VIEW_GET_PRIVATE (self);
+  priv->header_bar = gtk_header_bar_new ();
+
+  /* Make sure that the toolbar is not visible when using hte header bar */
+  toolbar = GTK_WIDGET (gtk_builder_get_object (priv->builder, "toolbar"));
+  gtk_widget_hide (toolbar);
+
+  /* First create the left side buttons */
+
+  _add_item_to_header_bar (self, HEADER_BAR_POSITION_START, "win.open-project", "document-open-symbolic", _("Open"), _("Open Existing Project"), "<Primary>o");
+  _add_item_to_header_bar (self, HEADER_BAR_POSITION_START, "win.add-pictures", "list-add-symbolic", _("Add"), _("Add Elements"), "<Primary>l");
+  _add_item_to_header_bar (self, HEADER_BAR_POSITION_START, "win.remove-pictures", "list-remove-symbolic", _("Remove"), _("Remove Elements"), "Delete");
+  _add_item_to_header_bar (self, HEADER_BAR_POSITION_START, "win.upload-all", "document-send-symbolic", _("Upload"), _("Upload All"), "<Primary>u");
+
+  /* Menu button and its associated menu */
+
+  full_path = g_strdup_printf ("%s/" UI_MENU_BUTTON_FILE, frogr_util_get_app_data_dir ());
+  gtk_builder_add_from_file (priv->builder, full_path, NULL);
+  g_free (full_path);
+
+  menu_model = G_MENU_MODEL (gtk_builder_get_object (priv->builder, "menu-button"));
+  extract_accels_from_menu (menu_model, priv->gtk_app);
+
+  menu = gtk_menu_new_from_model (menu_model);
+  gtk_widget_set_halign (menu, GTK_ALIGN_END);
+
+  g_action_map_add_action_entries (G_ACTION_MAP (self),
+                                   win_entries, G_N_ELEMENTS (win_entries),
+                                   self);
+
+  /* We add the menu button separately */
+
+  icon_theme = gtk_icon_theme_get_default ();
+  menu_image = gtk_icon_theme_has_icon (icon_theme, MENU_BUTTON_ICON)
+    ? gtk_image_new_from_icon_name (MENU_BUTTON_ICON, GTK_ICON_SIZE_MENU)
+    : gtk_image_new_from_icon_name (MENU_BUTTON_ICON_FALLBACK, GTK_ICON_SIZE_MENU);
+
+  header_item = gtk_menu_button_new ();
+  gtk_button_set_image (GTK_BUTTON (header_item), menu_image);
+  gtk_menu_button_set_popup (GTK_MENU_BUTTON (header_item), menu);
+  gtk_widget_show (header_item);
+  gtk_header_bar_pack_end (GTK_HEADER_BAR (priv->header_bar), header_item);
+
+  /* Save project item */
+
+  _add_item_to_header_bar (self, HEADER_BAR_POSITION_END, "win.save-project", "document-save-symbolic", _("Save"), _("Save Current Project"), "<Primary>s");
+
+  /* Make the close button visible and show */
+
+  gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (priv->header_bar), TRUE);
+  gtk_widget_show (priv->header_bar);
+}
+
+static void
+_add_item_to_header_bar (FrogrMainView *self, HeaderBarItemPosition pos, const gchar *action_name, const gchar *icon_name, const gchar *label, const gchar *tooltip_text, const gchar *accel)
+{
+  FrogrMainViewPrivate *priv = NULL;
+  GtkWidget *item = NULL;
+#if GTK_CHECK_VERSION (3, 12, 0)
+  const gchar *accels[2] = { accel, NULL };
+#endif
+
+  priv = FROGR_MAIN_VIEW_GET_PRIVATE (self);
+
+  item = gtk_button_new_from_icon_name (icon_name, GTK_ICON_SIZE_MENU);
+  gtk_widget_set_tooltip_text (item, tooltip_text);
+  gtk_actionable_set_action_name (GTK_ACTIONABLE (item), action_name);
+
+#if GTK_CHECK_VERSION (3, 12, 0)
+  gtk_application_set_accels_for_action (priv->gtk_app, action_name, accels);
+#else
+  gtk_application_add_accelerator (priv->gtk_app, accel, action_name, NULL);
+#endif
+
+  if (pos == HEADER_BAR_POSITION_START)
+    gtk_header_bar_pack_start (GTK_HEADER_BAR (priv->header_bar), item);
+  else
+    gtk_header_bar_pack_end (GTK_HEADER_BAR (priv->header_bar), item);
+
+  gtk_widget_show (item);
+}
+
+#else /* !USE_HEADER_BAR */
+
+static void _initialize_menubar_and_toolbar (FrogrMainView *self)
+{
+  FrogrMainViewPrivate *priv = NULL;
+  GtkWidget *toolbar = NULL;
+  GtkToolItem *toolbar_items[7];
+  gchar *full_path = NULL;
+  gint i;
+
+  priv = FROGR_MAIN_VIEW_GET_PRIVATE (self);
+
+  /* Menu bar */
+  full_path = g_strdup_printf ("%s/" UI_MENU_BAR_FILE, frogr_util_get_app_data_dir ());
+  gtk_builder_add_from_file (priv->builder, full_path, NULL);
+  g_free (full_path);
+
+  g_action_map_add_action_entries (G_ACTION_MAP (self),
+                                   win_entries, G_N_ELEMENTS (win_entries),
+                                   self);
+
+  gtk_application_set_menubar (gtk_window_get_application (GTK_WINDOW (self)),
+                               G_MENU_MODEL (gtk_builder_get_object (priv->builder, "menu-bar")));
+  gtk_application_window_set_show_menubar (GTK_APPLICATION_WINDOW (self), TRUE);
+
+  /* Toolbar */
+  toolbar = GTK_WIDGET (gtk_builder_get_object (priv->builder, "toolbar"));
+  gtk_widget_show (toolbar);
+
+  toolbar_items[0] = _create_toolbar_item ("win.open-project", "document-open", _("Open"), _("Open Existing Project"));
+  toolbar_items[1] = _create_toolbar_item ("win.save-project", "document-save", _("Save"), _("Save Current Project"));
+  toolbar_items[2] = gtk_separator_tool_item_new ();
+  toolbar_items[3] = _create_toolbar_item ("win.add-pictures", "list-add", _("Add"), _("Add Elements"));
+  toolbar_items[4] = _create_toolbar_item ("win.remove-pictures", "list-remove", _("Remove"), _("Remove Elements"));
+  toolbar_items[5] = gtk_separator_tool_item_new ();
+  toolbar_items[6] = _create_toolbar_item ("win.upload-all", "go-up", _("Upload"), _("Upload All"));
+
+  for (i = 0; i < G_N_ELEMENTS (toolbar_items); ++i)
+    gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolbar_items[i], i);
+
+  gtk_style_context_add_class (gtk_widget_get_style_context (toolbar),
+                               GTK_STYLE_CLASS_PRIMARY_TOOLBAR);
+}
+
 static GtkToolItem *
 _create_toolbar_item (const gchar *action_name, const gchar *icon_name, const gchar *label, const gchar *tooltip_text)
 {
@@ -584,6 +784,7 @@ _create_toolbar_item (const gchar *action_name, const gchar *icon_name, const gc
 
   return item;
 }
+#endif
 
 static gboolean
 _maybe_show_auth_dialog_on_idle (FrogrMainView *self)
@@ -662,6 +863,26 @@ _update_window_title (FrogrMainView *self, gboolean dirty)
 {
   FrogrMainViewPrivate *priv = FROGR_MAIN_VIEW_GET_PRIVATE (self);
 
+#if USE_HEADER_BAR
+  gchar *title = NULL;
+  gchar *subtitle = NULL;
+
+  title = priv->project_name
+    ? g_strdup_printf ("%s%s", (dirty ? "*" : ""), priv->project_name)
+    : g_strdup (APP_SHORTNAME);
+
+  subtitle = priv->project_name
+    ? g_strdup_printf ("%s", priv->project_dir)
+    : NULL;
+
+  gtk_header_bar_set_title (GTK_HEADER_BAR (priv->header_bar), title);
+  gtk_header_bar_set_subtitle (GTK_HEADER_BAR (priv->header_bar), subtitle);
+
+  g_free (subtitle);
+  g_free (title);
+
+#else /* !USE_HEADER_BAR */
+
   gchar *session_string = NULL;
   gchar *window_title = NULL;
 
@@ -675,6 +896,7 @@ _update_window_title (FrogrMainView *self, gboolean dirty)
 
   gtk_window_set_title (GTK_WINDOW (self), window_title);
   g_free (window_title);
+#endif
 }
 
 static void
@@ -816,8 +1038,10 @@ _on_toggle_menu_item_changed (GSimpleAction *action, GVariant *parameter, gpoint
 static void
 _quit_application (FrogrMainView *self)
 {
-  GtkApplication *gtk_app = gtk_window_get_application (GTK_WINDOW (self));
-  g_application_quit (G_APPLICATION (gtk_app));
+  FrogrMainViewPrivate *priv = NULL;
+
+  priv = FROGR_MAIN_VIEW_GET_PRIVATE (self);
+  g_application_quit (G_APPLICATION (priv->gtk_app));
 }
 
 #ifdef PLATFORM_MAC
@@ -826,8 +1050,6 @@ _tweak_app_menu_for_mac (FrogrMainView *self)
 {
   FrogrMainViewPrivate *priv = NULL;
   GMenuModel *menu = NULL;
-  /* GtkOSXApplication *osx_app = NULL; */
-  /* GtkWidget *menu_item = NULL; */
 
   priv = FROGR_MAIN_VIEW_GET_PRIVATE (self);
 
@@ -887,11 +1109,8 @@ _populate_accounts_submenu (FrogrMainView *self)
 
       if (frogr_account_is_active (account))
         {
-          GtkApplication *gtk_app = NULL;
           GAction *action = NULL;
-
-          gtk_app = gtk_window_get_application (GTK_WINDOW (self));
-          action = g_action_map_lookup_action (G_ACTION_MAP (gtk_app), ACTION_LOGIN_AS);
+          action = g_action_map_lookup_action (G_ACTION_MAP (priv->gtk_app), ACTION_LOGIN_AS);
           g_action_activate (action, g_variant_new_string (username));
         }
     }
@@ -1406,6 +1625,8 @@ _open_project_dialog (FrogrMainView *self)
   g_signal_connect (G_OBJECT (dialog), "response",
                     G_CALLBACK (_open_project_dialog_response_cb), self);
 
+  gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
+
   gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
   gtk_widget_show_all (dialog);
 }
@@ -1479,6 +1700,8 @@ _save_project_as_dialog (FrogrMainView *self)
   g_signal_connect (G_OBJECT (dialog), "response",
                     G_CALLBACK (_save_project_as_dialog_response_cb), self);
 
+  gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
+
   gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
   gtk_widget_show_all (dialog);
 }
@@ -1558,6 +1781,8 @@ _load_pictures_dialog (FrogrMainView *self)
   g_signal_connect (G_OBJECT (dialog), "response",
                     G_CALLBACK (_load_pictures_dialog_response_cb), self);
 
+  gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
+
   gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
   gtk_widget_show_all (dialog);
 }
@@ -2352,7 +2577,6 @@ frogr_main_view_new (GtkApplication *app)
   FrogrMainView *mainview =
     FROGR_MAIN_VIEW (g_object_new (FROGR_TYPE_MAIN_VIEW,
                                    "application", app,
-                                   "show-menubar", TRUE,
                                    NULL));
 
   /* Now initialize all the stuff strictly related to the UI */
