@@ -59,6 +59,7 @@ struct _FrogrPicturePrivate
   FrogrLocation *location;
   gboolean show_in_search;
   gboolean send_location;
+  gboolean replace_date_posted;
 
   gboolean is_video;
 
@@ -88,6 +89,7 @@ enum  {
   PROP_LOCATION,
   PROP_SHOW_IN_SEARCH,
   PROP_SEND_LOCATION,
+  PROP_REPLACE_DATE_POSTED,
   PROP_IS_VIDEO,
   PROP_FILESIZE,
   PROP_DATETIME,
@@ -455,6 +457,9 @@ _frogr_picture_set_property (GObject *object,
     case PROP_SEND_LOCATION:
       frogr_picture_set_send_location (self, g_value_get_boolean (value));
       break;
+    case PROP_REPLACE_DATE_POSTED:
+      frogr_picture_set_replace_date_posted (self, g_value_get_boolean (value));
+      break;
     case PROP_IS_VIDEO:
       priv->is_video = g_value_get_boolean (value);
       break;
@@ -528,6 +533,9 @@ _frogr_picture_get_property (GObject *object,
     case PROP_SEND_LOCATION:
       g_value_set_boolean (value, priv->send_location);
       break;
+    case PROP_REPLACE_DATE_POSTED:
+      g_value_set_boolean (value, priv->replace_date_posted);
+      break;
     case PROP_IS_VIDEO:
       g_value_set_boolean (value, priv->is_video);
       break;
@@ -725,6 +733,14 @@ frogr_picture_class_init(FrogrPictureClass *klass)
                                                          "to flickr, if available",
                                                          FALSE,
                                                          G_PARAM_READWRITE));
+  g_object_class_install_property (obj_class,
+                                   PROP_REPLACE_DATE_POSTED,
+                                   g_param_spec_boolean ("replace-date-posted",
+                                                         "replace-date-posted",
+                                                         "Whether to replace the 'date posted'"
+                                                         "with 'date taken', after uploading",
+                                                         FALSE,
+                                                         G_PARAM_READWRITE));
   g_object_class_install_property (obj_class,
                                    PROP_FILESIZE,
                                    g_param_spec_uint ("filesize",
@@ -788,6 +804,7 @@ frogr_picture_init (FrogrPicture *self)
 
   priv->show_in_search = TRUE;
   priv->send_location = FALSE;
+  priv->replace_date_posted = FALSE;
 
   priv->is_video = FALSE;
 
@@ -1129,6 +1146,29 @@ frogr_picture_set_location (FrogrPicture *self, FrogrLocation *location)
   priv->location = FROGR_IS_LOCATION (location) ? g_object_ref (location) : NULL;
 }
 
+gboolean
+frogr_picture_show_in_search (FrogrPicture *self)
+{
+  FrogrPicturePrivate *priv = NULL;
+
+  g_return_val_if_fail(FROGR_IS_PICTURE(self), FALSE);
+
+  priv = FROGR_PICTURE_GET_PRIVATE (self);
+  return priv->show_in_search;
+}
+
+void
+frogr_picture_set_show_in_search (FrogrPicture *self,
+                                  gboolean show_in_search)
+{
+  FrogrPicturePrivate *priv = NULL;
+
+  g_return_if_fail(FROGR_IS_PICTURE(self));
+
+  priv = FROGR_PICTURE_GET_PRIVATE (self);
+  priv->show_in_search = show_in_search;
+}
+
 gboolean
 frogr_picture_send_location (FrogrPicture *self)
 {
@@ -1152,26 +1192,25 @@ frogr_picture_set_send_location (FrogrPicture *self, gboolean send_location)
 }
 
 gboolean
-frogr_picture_show_in_search (FrogrPicture *self)
+frogr_picture_replace_date_posted (FrogrPicture *self)
 {
   FrogrPicturePrivate *priv = NULL;
 
   g_return_val_if_fail(FROGR_IS_PICTURE(self), FALSE);
 
   priv = FROGR_PICTURE_GET_PRIVATE (self);
-  return priv->show_in_search;
+  return priv->replace_date_posted;
 }
 
 void
-frogr_picture_set_show_in_search (FrogrPicture *self,
-                                  gboolean show_in_search)
+frogr_picture_set_replace_date_posted (FrogrPicture *self, gboolean replace_date_posted)
 {
   FrogrPicturePrivate *priv = NULL;
 
   g_return_if_fail(FROGR_IS_PICTURE(self));
 
   priv = FROGR_PICTURE_GET_PRIVATE (self);
-  priv->show_in_search = show_in_search;
+  priv->replace_date_posted = replace_date_posted;
 }
 
 GdkPixbuf *
