@@ -109,13 +109,16 @@ void frogr_picture_set_license (FrogrPicture *self, FspLicense license);
 FrogrLocation *frogr_picture_get_location (FrogrPicture *self);
 void frogr_picture_set_location (FrogrPicture *self, FrogrLocation *location);
 
-gboolean frogr_picture_send_location (FrogrPicture *self);
-void frogr_picture_set_send_location (FrogrPicture *self, gboolean send_location);
-
 gboolean frogr_picture_show_in_search (FrogrPicture *self);
 void frogr_picture_set_show_in_search (FrogrPicture *self,
                                        gboolean show_in_search);
 
+gboolean frogr_picture_send_location (FrogrPicture *self);
+void frogr_picture_set_send_location (FrogrPicture *self, gboolean send_location);
+
+gboolean frogr_picture_replace_date_posted (FrogrPicture *self);
+void frogr_picture_set_replace_date_posted (FrogrPicture *self, gboolean replace_date_posted);
+
 GdkPixbuf *frogr_picture_get_pixbuf (FrogrPicture *self);
 void frogr_picture_set_pixbuf (FrogrPicture *self,
                                GdkPixbuf *pixbuf);
