@@ -1,7 +1,7 @@
 /*
  * frogr-settings-dialog.c -- Main settings dialog
  *
- * Copyright (C) 2009-2014 Mario Sanchez Prada
+ * Copyright (C) 2009-2015 Mario Sanchez Prada
  * Authors: Mario Sanchez Prada <msanchez@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -46,6 +46,7 @@ typedef struct _FrogrSettingsDialogPrivate {
   GtkWidget *family_cb;
   GtkWidget *show_in_search_cb;
   GtkWidget *send_geolocation_data_cb;
+  GtkWidget *replace_date_posted_cb;
   GtkWidget *license_cb;
   GtkWidget *photo_content_rb;
   GtkWidget *sshot_content_rb;
@@ -74,6 +75,7 @@ typedef struct _FrogrSettingsDialogPrivate {
   gboolean friend_visibility;
   gboolean show_in_search;
   gboolean send_geolocation_data;
+  gboolean replace_date_posted;
   gboolean enable_tags_autocompletion;
   gboolean keep_file_extensions;
   gboolean import_tags;
@@ -164,11 +166,10 @@ _add_general_page (FrogrSettingsDialog *self, GtkNotebook *notebook)
 {
   FrogrSettingsDialogPrivate *priv = NULL;
   GtkWidget *vbox = NULL;
+  GtkWidget *gbox = NULL;
   GtkWidget *box1 = NULL;
   GtkWidget *box2 = NULL;
   GtkWidget *box3 = NULL;
-  GtkWidget *box4 = NULL;
-  GtkWidget *align = NULL;
   GtkWidget *label = NULL;
   GtkWidget *combo = NULL;
   gchar *markup = NULL;
@@ -176,11 +177,13 @@ _add_general_page (FrogrSettingsDialog *self, GtkNotebook *notebook)
 
   priv = FROGR_SETTINGS_DIALOG_GET_PRIVATE (self);
 
-  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-  gtk_box_set_homogeneous (GTK_BOX (vbox), FALSE);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
 
   /* Default Visibility */
 
+  gbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+  gtk_box_pack_start (GTK_BOX (vbox), gbox, FALSE, FALSE, 0);
+
   label = gtk_label_new (NULL);
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
   markup = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>",
@@ -188,45 +191,38 @@ _add_general_page (FrogrSettingsDialog *self, GtkNotebook *notebook)
   gtk_label_set_markup (GTK_LABEL (label), markup);
   g_free (markup);
 
-  align = gtk_alignment_new (0, 0, 0, 1);
-  gtk_container_add (GTK_CONTAINER (align), label);
-  gtk_box_pack_start (GTK_BOX (vbox), align, FALSE, FALSE, 6);
+  gtk_widget_set_halign (label, GTK_ALIGN_START);
+  gtk_box_pack_start (GTK_BOX (gbox), label, FALSE, FALSE, 0);
 
   box1 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-  gtk_box_set_homogeneous (GTK_BOX (box1), FALSE);
-  box2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
-  gtk_box_set_homogeneous (GTK_BOX (box2), FALSE);
+  box2 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 
-  box3 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
-  gtk_box_set_homogeneous (GTK_BOX (box3), FALSE);
-
-  _add_toggleable_item (self, GTK_BOX (box3), NULL,
+  _add_toggleable_item (self, GTK_BOX (box2), NULL,
                         TRUE, _("_Private"), &priv->private_rb);
 
-  _add_toggleable_item (self, GTK_BOX (box3), GTK_RADIO_BUTTON (priv->private_rb),
+  _add_toggleable_item (self, GTK_BOX (box2), GTK_RADIO_BUTTON (priv->private_rb),
                         FALSE, _("P_ublic"), &priv->public_rb);
 
-  gtk_box_pack_start (GTK_BOX (box2), box3, FALSE, FALSE, 0);
-
-  box3 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
-  gtk_box_set_homogeneous (GTK_BOX (box3), FALSE);
-
-  box4 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
-  gtk_box_set_homogeneous (GTK_BOX (box4), FALSE);
-
-  _add_toggleable_item (self, GTK_BOX (box4), NULL, FALSE,
-                        _("_Family"), &priv->family_cb);
-  _add_toggleable_item (self, GTK_BOX (box4), NULL, FALSE,
-                        _("F_riends"), &priv->friend_cb);
-
-  gtk_box_pack_start (GTK_BOX (box3), box4, FALSE, FALSE, 12);
-  gtk_box_pack_start (GTK_BOX (box2), box3, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (box1), box2, FALSE, FALSE, 0);
 
-  gtk_box_pack_start (GTK_BOX (vbox), box1, FALSE, FALSE, 0);
+  box2 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+  box3 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+
+  _add_toggleable_item (self, GTK_BOX (box3), NULL, FALSE,
+                        _("_Family"), &priv->family_cb);
+  _add_toggleable_item (self, GTK_BOX (box3), NULL, FALSE,
+                        _("F_riends"), &priv->friend_cb);
+
+  gtk_box_pack_start (GTK_BOX (box2), box3, FALSE, FALSE, 12);
+  gtk_box_pack_start (GTK_BOX (box1), box2, FALSE, FALSE, 0);
+
+  gtk_box_pack_start (GTK_BOX (gbox), box1, FALSE, FALSE, 0);
 
   /* Default Content type */
 
+  gbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+  gtk_box_pack_start (GTK_BOX (vbox), gbox, FALSE, FALSE, 0);
+
   label = gtk_label_new (NULL);
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
   markup = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>",
@@ -234,12 +230,10 @@ _add_general_page (FrogrSettingsDialog *self, GtkNotebook *notebook)
   gtk_label_set_markup (GTK_LABEL (label), markup);
   g_free (markup);
 
-  align = gtk_alignment_new (0, 0, 0, 1);
-  gtk_container_add (GTK_CONTAINER (align), label);
-  gtk_box_pack_start (GTK_BOX (vbox), align, FALSE, FALSE, 6);
+  gtk_widget_set_halign (label, GTK_ALIGN_START);
+  gtk_box_pack_start (GTK_BOX (gbox), label, FALSE, FALSE, 0);
 
-  box1 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
-  gtk_box_set_homogeneous (GTK_BOX (box1), FALSE);
+  box1 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 
   _add_toggleable_item (self, GTK_BOX (box1), NULL, TRUE,
                         _("P_hoto"), &priv->photo_content_rb);
@@ -248,10 +242,13 @@ _add_general_page (FrogrSettingsDialog *self, GtkNotebook *notebook)
   _add_toggleable_item (self, GTK_BOX (box1), GTK_RADIO_BUTTON (priv->photo_content_rb),
                         FALSE, _("Oth_er"), &priv->other_content_rb);
 
-  gtk_box_pack_start (GTK_BOX (vbox), box1, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (gbox), box1, FALSE, FALSE, 0);
 
   /* Default Safety level */
 
+  gbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+  gtk_box_pack_start (GTK_BOX (vbox), gbox, FALSE, FALSE, 0);
+
   label = gtk_label_new (NULL);
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
   markup = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>",
@@ -259,12 +256,10 @@ _add_general_page (FrogrSettingsDialog *self, GtkNotebook *notebook)
   gtk_label_set_markup (GTK_LABEL (label), markup);
   g_free (markup);
 
-  align = gtk_alignment_new (0, 0, 0, 1);
-  gtk_container_add (GTK_CONTAINER (align), label);
-  gtk_box_pack_start (GTK_BOX (vbox), align, FALSE, FALSE, 6);
+  gtk_widget_set_halign (label, GTK_ALIGN_START);
+  gtk_box_pack_start (GTK_BOX (gbox), label, FALSE, FALSE, 0);
 
-  box1 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
-  gtk_box_set_homogeneous (GTK_BOX (box1), FALSE);
+  box1 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 
   _add_toggleable_item (self, GTK_BOX (box1), NULL, TRUE,
                         _("S_afe"), &priv->safe_rb);
@@ -273,10 +268,13 @@ _add_general_page (FrogrSettingsDialog *self, GtkNotebook *notebook)
   _add_toggleable_item (self, GTK_BOX (box1), GTK_RADIO_BUTTON (priv->safe_rb),
                         FALSE, _("Restr_icted"), &priv->restricted_rb);
 
-  gtk_box_pack_start (GTK_BOX (vbox), box1, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (gbox), box1, FALSE, FALSE, 0);
 
   /* License type */
 
+  gbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+  gtk_box_pack_start (GTK_BOX (vbox), gbox, FALSE, FALSE, 0);
+
   label = gtk_label_new (NULL);
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
   markup = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>",
@@ -284,15 +282,14 @@ _add_general_page (FrogrSettingsDialog *self, GtkNotebook *notebook)
   gtk_label_set_markup (GTK_LABEL (label), markup);
   g_free (markup);
 
-  align = gtk_alignment_new (0, 0, 0, 1);
-  gtk_container_add (GTK_CONTAINER (align), label);
-  gtk_box_pack_start (GTK_BOX (vbox), align, FALSE, FALSE, 6);
+  gtk_widget_set_halign (label, GTK_ALIGN_START);
+  gtk_box_pack_start (GTK_BOX (gbox), label, FALSE, FALSE, 0);
 
   combo = gtk_combo_box_text_new ();
   for (i = 0; license_descriptions[i]; i++)
     gtk_combo_box_text_insert (GTK_COMBO_BOX_TEXT (combo), i, NULL, _(license_descriptions[i]));
 
-  gtk_box_pack_start (GTK_BOX (vbox), combo, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (gbox), combo, FALSE, FALSE, 0);
   priv->license_cb = combo;
 
   g_signal_connect (G_OBJECT (priv->license_cb), "changed",
@@ -301,6 +298,9 @@ _add_general_page (FrogrSettingsDialog *self, GtkNotebook *notebook)
 
   /* Other defaults */
 
+  gbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+  gtk_box_pack_start (GTK_BOX (vbox), gbox, FALSE, FALSE, 0);
+
   label = gtk_label_new (NULL);
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
   markup = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>",
@@ -308,23 +308,24 @@ _add_general_page (FrogrSettingsDialog *self, GtkNotebook *notebook)
   gtk_label_set_markup (GTK_LABEL (label), markup);
   g_free (markup);
 
-  align = gtk_alignment_new (0, 0, 0, 1);
-  gtk_container_add (GTK_CONTAINER (align), label);
-  gtk_box_pack_start (GTK_BOX (vbox), align, FALSE, FALSE, 6);
+  gtk_widget_set_halign (label, GTK_ALIGN_START);
+  gtk_box_pack_start (GTK_BOX (gbox), label, FALSE, FALSE, 0);
 
   box1 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-  gtk_box_set_homogeneous (GTK_BOX (box1), FALSE);
 
+  _add_toggleable_item (self, GTK_BOX (box1), NULL, FALSE,
+                        _("_Show Pictures in Global Search Results"),
+                        &priv->show_in_search_cb);
   _add_toggleable_item (self, GTK_BOX (box1), NULL, FALSE,
                         _("Set Geo_location Information for Pictures"),
                         &priv->send_geolocation_data_cb);
   _add_toggleable_item (self, GTK_BOX (box1), NULL, FALSE,
-                        _("_Show Pictures in Global Search Results"),
-                        &priv->show_in_search_cb);
+                        _("Replace 'Date Posted' with 'Date Taken' for Pictures"),
+                        &priv->replace_date_posted_cb);
 
-  gtk_box_pack_start (GTK_BOX (vbox), box1, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (gbox), box1, FALSE, FALSE, 0);
 
-  gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
+  gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
   gtk_notebook_append_page (notebook, vbox, gtk_label_new_with_mnemonic (_("_General")));
 }
 
@@ -334,7 +335,6 @@ _add_connection_page (FrogrSettingsDialog *self, GtkNotebook *notebook)
   FrogrSettingsDialogPrivate *priv = NULL;
   GtkWidget *vbox = NULL;
   GtkWidget *grid = NULL;
-  GtkWidget *align = NULL;
   GtkWidget *cbutton = NULL;
   GtkWidget *label = NULL;
   GtkWidget *entry = NULL;
@@ -343,7 +343,6 @@ _add_connection_page (FrogrSettingsDialog *self, GtkNotebook *notebook)
   priv = FROGR_SETTINGS_DIALOG_GET_PRIVATE (self);
 
   vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-  gtk_box_set_homogeneous (GTK_BOX (vbox), FALSE);
 
   /* Proxy settings */
 
@@ -354,23 +353,20 @@ _add_connection_page (FrogrSettingsDialog *self, GtkNotebook *notebook)
   gtk_label_set_markup (GTK_LABEL (label), markup);
   g_free (markup);
 
-  align = gtk_alignment_new (0, 0, 0, 1);
-  gtk_container_add (GTK_CONTAINER (align), label);
-  gtk_box_pack_start (GTK_BOX (vbox), align, FALSE, FALSE, 6);
+  gtk_widget_set_halign (label, GTK_ALIGN_START);
+  gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 
   /* Enable proxy */
 
   cbutton = gtk_check_button_new_with_mnemonic (_("_Enable HTTP Proxy"));
-  align = gtk_alignment_new (0, 0, 0, 0);
-  gtk_container_add (GTK_CONTAINER (align), cbutton);
-  gtk_box_pack_start (GTK_BOX (vbox), align, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), cbutton, FALSE, FALSE, 0);
   priv->use_proxy_cb = cbutton;
 
   /* Proxy host */
 
   grid = gtk_grid_new ();
   gtk_grid_set_row_spacing (GTK_GRID (grid), 6);
-  gtk_grid_set_column_spacing (GTK_GRID (grid), 6);
+  gtk_grid_set_column_spacing (GTK_GRID (grid), 12);
 
   label = gtk_label_new_with_mnemonic (_("_Host:"));
   gtk_widget_set_halign (GTK_WIDGET (label), GTK_ALIGN_END);
@@ -434,7 +430,7 @@ _add_connection_page (FrogrSettingsDialog *self, GtkNotebook *notebook)
                     G_CALLBACK (_proxy_port_inserted_cb),
                     NULL);
 
-  gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
+  gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
   gtk_notebook_append_page (notebook, vbox, gtk_label_new_with_mnemonic (_("Connec_tion")));
 }
 
@@ -444,14 +440,12 @@ _add_misc_page (FrogrSettingsDialog *self, GtkNotebook *notebook)
   FrogrSettingsDialogPrivate *priv = NULL;
   GtkWidget *vbox = NULL;
   GtkWidget *box = NULL;
-  GtkWidget *align = NULL;
   GtkWidget *label = NULL;
   gchar *markup = NULL;
 
   priv = FROGR_SETTINGS_DIALOG_GET_PRIVATE (self);
 
   vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-  gtk_box_set_homogeneous (GTK_BOX (vbox), FALSE);
 
   /* Other Stuff */
 
@@ -462,12 +456,10 @@ _add_misc_page (FrogrSettingsDialog *self, GtkNotebook *notebook)
   gtk_label_set_markup (GTK_LABEL (label), markup);
   g_free (markup);
 
-  align = gtk_alignment_new (0, 0, 0, 1);
-  gtk_container_add (GTK_CONTAINER (align), label);
-  gtk_box_pack_start (GTK_BOX (vbox), align, FALSE, FALSE, 6);
+  gtk_widget_set_halign (label, GTK_ALIGN_START);
+  gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 
   box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-  gtk_box_set_homogeneous (GTK_BOX (box), FALSE);
 
   _add_toggleable_item (self, GTK_BOX (box), NULL, FALSE,
                         _("Ena_ble Tags Auto-Completion"),
@@ -486,7 +478,7 @@ _add_misc_page (FrogrSettingsDialog *self, GtkNotebook *notebook)
 
   gtk_box_pack_start (GTK_BOX (vbox), box, FALSE, FALSE, 0);
 
-  gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
+  gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
   gtk_notebook_append_page (notebook, vbox, gtk_label_new_with_mnemonic (_("_Misc")));
 }
 
@@ -500,8 +492,9 @@ _fill_dialog_with_data (FrogrSettingsDialog *self)
   priv->public_visibility = frogr_config_get_default_public (priv->config);
   priv->family_visibility = frogr_config_get_default_family (priv->config);
   priv->friend_visibility = frogr_config_get_default_friend (priv->config);
-  priv->send_geolocation_data = frogr_config_get_default_send_geolocation_data (priv->config);
   priv->show_in_search = frogr_config_get_default_show_in_search (priv->config);
+  priv->send_geolocation_data = frogr_config_get_default_send_geolocation_data (priv->config);
+  priv->replace_date_posted = frogr_config_get_default_replace_date_posted (priv->config);
   priv->license = frogr_config_get_default_license (priv->config);
   priv->content_type = frogr_config_get_default_content_type (priv->config);
   priv->safety_level = frogr_config_get_default_safety_level (priv->config);
@@ -541,10 +534,12 @@ _fill_dialog_with_data (FrogrSettingsDialog *self)
                                 priv->family_visibility);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->friend_cb),
                                 priv->friend_visibility);
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->send_geolocation_data_cb),
-                                priv->send_geolocation_data);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->show_in_search_cb),
                                 priv->show_in_search);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->send_geolocation_data_cb),
+                                priv->send_geolocation_data);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->replace_date_posted_cb),
+                                priv->replace_date_posted);
 
   if (priv->license >= FSP_LICENSE_NONE && priv->license < FSP_LICENSE_LAST)
     gtk_combo_box_set_active (GTK_COMBO_BOX (priv->license_cb), priv->license + 1);
@@ -602,8 +597,9 @@ _save_data (FrogrSettingsDialog *self)
   frogr_config_set_default_public (priv->config, priv->public_visibility);
   frogr_config_set_default_family (priv->config, priv->family_visibility);
   frogr_config_set_default_friend (priv->config, priv->friend_visibility);
-  frogr_config_set_default_send_geolocation_data (priv->config, priv->send_geolocation_data);
   frogr_config_set_default_show_in_search (priv->config, priv->show_in_search);
+  frogr_config_set_default_send_geolocation_data (priv->config, priv->send_geolocation_data);
+  frogr_config_set_default_replace_date_posted (priv->config, priv->replace_date_posted);
 
   frogr_config_set_default_license (priv->config, priv->license);
   frogr_config_set_default_content_type (priv->config, priv->content_type);
@@ -700,16 +696,22 @@ _on_button_toggled (GtkToggleButton *button, gpointer data)
       DEBUG ("friend visibility set to %s", active ? "TRUE" : "FALSE");
     }
 
+  if (GTK_WIDGET (button) == priv->show_in_search_cb)
+    {
+      priv->show_in_search = active;
+      DEBUG ("Show up in global search results set to %s", active ? "TRUE" : "FALSE");
+    }
+
   if (GTK_WIDGET (button) == priv->send_geolocation_data_cb)
     {
       priv->send_geolocation_data = active;
       DEBUG ("Send geolocation data set to %s", active ? "TRUE" : "FALSE");
     }
 
-  if (GTK_WIDGET (button) == priv->show_in_search_cb)
+  if (GTK_WIDGET (button) == priv->replace_date_posted_cb)
     {
-      priv->show_in_search = active;
-      DEBUG ("Show up in global search results set to %s", active ? "TRUE" : "FALSE");
+      priv->replace_date_posted = active;
+      DEBUG ("Replace 'Date _Posted' with 'Date Taken' set to %s", active ? "TRUE" : "FALSE");
     }
 
   if (active && GTK_WIDGET (button) == priv->photo_content_rb)
@@ -912,8 +914,9 @@ frogr_settings_dialog_init (FrogrSettingsDialog *self)
   priv->private_rb = NULL;
   priv->friend_cb = NULL;
   priv->family_cb = NULL;
-  priv->send_geolocation_data_cb = NULL;
   priv->show_in_search_cb = NULL;
+  priv->send_geolocation_data_cb = NULL;
+  priv->replace_date_posted_cb = NULL;
   priv->license_cb = NULL;
   priv->photo_content_rb = NULL;
   priv->sshot_content_rb = NULL;
@@ -937,8 +940,9 @@ frogr_settings_dialog_init (FrogrSettingsDialog *self)
   priv->public_visibility = FALSE;
   priv->family_visibility = FALSE;
   priv->friend_visibility = FALSE;
-  priv->send_geolocation_data = FALSE;
   priv->show_in_search = FALSE;
+  priv->send_geolocation_data = FALSE;
+  priv->replace_date_posted = TRUE;
   priv->license = FSP_LICENSE_NONE;
   priv->safety_level = FSP_SAFETY_LEVEL_NONE;
   priv->content_type = FSP_CONTENT_TYPE_NONE;
@@ -964,7 +968,7 @@ frogr_settings_dialog_init (FrogrSettingsDialog *self)
   vbox = gtk_dialog_get_content_area (GTK_DIALOG (self));
 
   notebook = GTK_NOTEBOOK (gtk_notebook_new ());
-  gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (notebook), TRUE, TRUE, 6);
+  gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (notebook), TRUE, TRUE, 0);
 
   _add_general_page (self, notebook);
   _add_connection_page (self, notebook);
@@ -979,8 +983,7 @@ frogr_settings_dialog_init (FrogrSettingsDialog *self)
                     G_CALLBACK (_on_dialog_delete_event),
                     NULL);
 
-  gtk_dialog_set_default_response (GTK_DIALOG (self),
-                                   GTK_RESPONSE_CLOSE);
+  gtk_dialog_set_default_response (GTK_DIALOG (self), GTK_RESPONSE_CLOSE);
 }
 
 
@@ -998,6 +1001,9 @@ frogr_settings_dialog_show (GtkWindow *parent)
                              "transient-for", parent,
                              "resizable", TRUE,
                              "title", _("Preferences"),
+#if GTK_CHECK_VERSION (3, 12, 0)
+                             "use-header-bar", USE_HEADER_BAR,
+#endif
                              NULL);
 
       _instance = FROGR_SETTINGS_DIALOG (object);
